package mpq.momometer.repositories;

import mqp.momometer.classes.ActivityData;
import mqp.momometer.classes.ActivityDataPoint;
import mqp.momometer.classes.ActivityCategory;
import mqp.momometer.helpers.DbSqlScript;
import mqp.momometer.helpers.HelperFunctions;
import android.content.Context;
import android.database.Cursor;
import android.database.sqlite.SQLiteDatabase;
import android.database.sqlite.SQLiteException;

public class ActivityDataAdapter {

	private final String DB_NAME = "momometerDb";
	private final String TABLE_NAME = DbSqlScript.ACTIVITY_INPUT;

	private SQLiteDatabase database;
	private Context context;

	private final String insertStmt = "insert into " + TABLE_NAME
			+ "(type, activity, duration, timestamp, week) values(";

	private final String deleteStmt = "delete from " + TABLE_NAME
			+ " where id == ";

	public ActivityDataAdapter(Context context) {
		this.context = context;
	}

	public boolean insertActivityData(ActivityData activity) {
		try {
			database = context.openOrCreateDatabase(DB_NAME,
					Context.MODE_PRIVATE, null);
			database.execSQL((insertStmt + activity.getType() + ","
					+ activity.getActivity() + "," 
					+ activity.getDuration() + ",'" 
					+ HelperFunctions.getTimeStampString() + "'," 
					+ HelperFunctions.getCurrentWeek(context) + ")"));
			database.close();
			return true;
		} catch (SQLiteException se) {
			return false;
		}
	}

	public ActivityDataPoint getActivityDataPointByWeek(int week)
	{
		try {
			String whereClause = "";
			if (week != 0)
			{
				whereClause = " AND week = " + week;
			}
			
			database = context.openOrCreateDatabase(DB_NAME,
					Context.MODE_PRIVATE, null);
			
			Cursor c = 	database.rawQuery("SELECT type, sum(" + DbSqlScript.TIME_DURATION + ".duration) as totalDuration " +
					 " FROM " + DbSqlScript.ACTIVITY_INPUT + ", " + DbSqlScript.TIME_DURATION + 
					 " WHERE " + DbSqlScript.ACTIVITY_INPUT + ".duration = " + DbSqlScript.TIME_DURATION + ".id" +  
					 whereClause + 					 
	                " GROUP BY type" , null);
			
	        int totalSedentaryTime = 0;
	        int totalActiveTime = 0;
	        int totalExerciseTime = 0;
	        
	         if (c != null) {
				if (c.moveToFirst()) {
					do {
						int type = c.getInt(c.getColumnIndex("type"));
						int duration = c.getInt(c.getColumnIndex("totalDuration"));										
						
						switch(type)
						{
							case ActivityCategory.STANDING:
								totalActiveTime = duration;
								break;
							case ActivityCategory.SITTING:
								totalSedentaryTime = duration;
								break;
							case ActivityCategory.EXERCISING:
								totalExerciseTime = duration;
								break;
						}
					} while (c.moveToNext());
				}
			}
	 		ActivityDataPoint result = new ActivityDataPoint(totalActiveTime, totalSedentaryTime, totalExerciseTime); 
			c.close();
			database.close();

			return result;

		} catch (SQLiteException se) {
			throw se;
		}
	}
	
	public void deleteActivity(int id) {
		try {
			database = context.openOrCreateDatabase(DB_NAME,
					Context.MODE_PRIVATE, null);
			database.execSQL(deleteStmt + id);
			database.close();
		} catch (SQLiteException se) {

		}
	}
}
