package mpq.momometer.repositories;

import java.util.ArrayList;
import java.util.Date;

import mqp.momometer.classes.FoodDataPoint;
import mqp.momometer.classes.FoodDataPointSet;
import mqp.momometer.classes.FoodItem;
import mqp.momometer.classes.FoodData;
import mqp.momometer.helpers.DbSqlScript;
import mqp.momometer.helpers.HelperFunctions;
import android.content.Context;
import android.database.Cursor;
import android.database.sqlite.SQLiteDatabase;
import android.database.sqlite.SQLiteException;

public class FoodDataAdapter {
	
	private final String DB_NAME = "momometerDb";
	private final String TABLE_NAME = DbSqlScript.FOOD_INPUT;

	private final String insertStmt = "insert into " + TABLE_NAME
	+ "(foodId, servings, mealType, timestamp, dayofweek, week, dayofmonth, month, year) values(";
	
	private SQLiteDatabase database;
	private Context context;
	
	public FoodDataAdapter(Context context)
	{
		this.context = context;
	}
	
	public boolean insertFood(FoodItem food, int mealType)
	{
		try {
			database = context.openOrCreateDatabase(DB_NAME,
					Context.MODE_PRIVATE, null);
			Date timestamp = HelperFunctions.getTimeStamp();
			
			database.execSQL((insertStmt + food.getId() + ","
					+ food.getServings() + "," 
					+ mealType + ",'" 
					+ HelperFunctions.getTimeStampString() + "',"
					+ timestamp.getDay() + ","
					+ HelperFunctions.getCurrentWeek(context) + "," 
					+ timestamp.getDate() + ","
					+ (timestamp.getMonth() + 1) + ","
					+ timestamp.getYear() + ")"));
			database.close();
			return true;
		} catch (SQLiteException se) {
			throw se;
			//return false;
		}		
	}
	
	public boolean insertFoods(FoodItem[] foods, int mealType)
	{
		for (FoodItem food : foods)
		{
			insertFood(food, mealType);
		}		
		return true;
	}
	
	public FoodData[] getFoodData() {
		try {
			ArrayList<FoodData> results = new ArrayList<FoodData>();
			database = context.openOrCreateDatabase(DB_NAME,
					Context.MODE_PRIVATE, null);

			Cursor c = database.rawQuery("SELECT name, description, category, calories, image, foodId, servings, mealType, timestamp, week" +
					                     " FROM " + DbSqlScript.FOOD_LIST + ", " + DbSqlScript.FOOD_INPUT + 
					                     " WHERE " + DbSqlScript.FOOD_INPUT + ".foodId = " + DbSqlScript.FOOD_LIST + ".id", null);
			if (c != null) {
				if (c.moveToFirst()) {
					do {
						int id = c.getInt(c.getColumnIndex("foodId"));
						String name = c.getString(c.getColumnIndex("name"));
						int mealType = c.getInt(c.getColumnIndex("mealType"));
						String description = c.getString(c.getColumnIndex("description"));
						int category = c.getInt(c.getColumnIndex("category"));
						int calories = c.getInt(c.getColumnIndex("calories"));
						int image = c.getInt(c.getColumnIndex("image"));
						int servings = c.getInt(c.getColumnIndex("servings"));	
						Date timestamp = new Date(c.getString(c.getColumnIndex("timestamp")));
						int week = c.getInt(c.getColumnIndex("week"));	
						FoodData food = new FoodData(id, category, name, description, calories, image, servings, mealType, timestamp, week);
						//Food food = new Food(id,0,mealType,null,null,0,0,servings);
						results.add(food);

					} while (c.moveToNext());
				}
			}
			c.close();
			database.close();

			return (FoodData[]) results
					.toArray(new FoodData[results.size()]);

		} catch (SQLiteException se) {
			
		}
		return null;
	}
	
	
	/**
	 * Returns the total calorific intake for the given day and week
	 * @param day
	 * @param week
	 * @return
	 */
	public double getCaloriesByDay(int day, int week)
	{
		database = context.openOrCreateDatabase(DB_NAME,
				Context.MODE_PRIVATE, null);
		
		Cursor c = database.rawQuery("SELECT sum(calories * servings) as totalcal" +
					 " FROM " + DbSqlScript.FOOD_LIST + ", " + DbSqlScript.FOOD_INPUT + 
		             " WHERE " + DbSqlScript.FOOD_INPUT + ".foodId = " + DbSqlScript.FOOD_LIST + ".id and week = " + week + " and dayofweek = " + day +			             
                     " GROUP BY dayofweek", null);
		double totalCalories = 0;

		if (c != null) {
			if (c.moveToFirst()) {
				do {
					totalCalories = c.getFloat(c.getColumnIndex("totalcal"));					
				} while (c.moveToNext());
			}
		}
		c.close();
		database.close();

		return totalCalories;
	}
	
	/**
	 * Returns the total servings of vegetables 
	 */
	public int getVegetableServingsByDay(int day, int week){
		database = context.openOrCreateDatabase(DB_NAME,
				Context.MODE_PRIVATE, null);
		
		Cursor c = database.rawQuery("SELECT sum(servings) as totalServings" +
					 " FROM " + DbSqlScript.FOOD_LIST + ", " + DbSqlScript.FOOD_INPUT + 
		             " WHERE " + DbSqlScript.FOOD_INPUT + ".foodId = " + DbSqlScript.FOOD_LIST + ".id " +
		             " and " + DbSqlScript.FOOD_LIST + ".category = 1" + // Veg category
		             " and week = " + week + " and dayofweek = " + day , null);
		
		int totalVegetableServings= 0;

		if (c != null) {
			if (c.moveToFirst()) {
				do {
					totalVegetableServings = c.getInt(c.getColumnIndex("totalServings"));					
				} while (c.moveToNext());
			}
		}
		c.close();
		database.close();

		return totalVegetableServings;
	}
	
	/**
	 * Return the sum of calories by time frame (weeks, days)
	 * @return
	 */
	public FoodDataPointSet getFoodDataPoints(int week)
	{
		String time = "";		

		try {
		FoodDataPointSet results = new FoodDataPointSet();
		database = context.openOrCreateDatabase(DB_NAME,
				Context.MODE_PRIVATE, null);
		
		Cursor c = null;
		if (week == 0)
		{			
			time = "week";
			c = database.rawQuery("SELECT (sum(calories * servings) / 7) as avgcal, week " +
					 " FROM " + DbSqlScript.FOOD_LIST + ", " + DbSqlScript.FOOD_INPUT + 
		             " WHERE " + DbSqlScript.FOOD_INPUT + ".foodId = " + DbSqlScript.FOOD_LIST + ".id" +			            
                    " GROUP BY week" , null);
		}
		else 
		{
			time = "dayofweek";
			c = database.rawQuery("SELECT sum(calories * servings) as avgcal, dayofweek " +
					 " FROM " + DbSqlScript.FOOD_LIST + ", " + DbSqlScript.FOOD_INPUT + 
		             " WHERE " + DbSqlScript.FOOD_INPUT + ".foodId = " + DbSqlScript.FOOD_LIST + ".id and week = " + week + 			             
                     " GROUP BY dayofweek", null);
		}

		if (c != null) {
			if (c.moveToFirst()) {
				do {
					int calories = c.getInt(c.getColumnIndex("avgcal"));
					int timeunit = c.getInt(c.getColumnIndex(time));
					FoodDataPoint dp = new FoodDataPoint(timeunit,calories, 0);	
					
					//Food food = new Food(id,0,mealType,null,null,0,0,servings);
					results.put(dp);

				} while (c.moveToNext());
			}
		}
		c.close();
		database.close();

		return results;

	} catch (SQLiteException se) {
		throw se;
	}
	//return null;
	}
}
