package mpq.momometer.repositories;

import java.util.Comparator;
import java.util.LinkedHashMap;
import java.util.List;
import java.util.Map;
import java.util.Set;
import java.util.TreeSet;

import android.accounts.Account;
import android.accounts.AccountManager;
import android.content.Context;
import android.content.Intent;
import android.content.SharedPreferences;
import android.os.Bundle;
import android.util.Log;

import mqp.momometer.health.HealthGDataClient;
import mqp.momometer.health.Result;
import mqp.momometer.health.HealthGDataClient.AuthenticationException;
import mqp.momometer.health.HealthGDataClient.InvalidProfileException;
import mqp.momometer.health.Test;

public class HealthRepository {

	/**
	 * Set this to 'weaver' to connect to H9, and 'health' to connect to Health.
	 */
	private static final String SERVICE_NAME = "health";

	private static final String LOG_TAG = "AndroidHealthClient";

	private static final int ACTIVITY_AUTHENTICATE = 0;
	private static final int ACTIVITY_ADD_RESULT = 1;

	private static final String PREF = "MyPrefs";

	private static final int DIALOG_ACCOUNTS = 0;
	private static final int DIALOG_PROFILES = 1;

	private static final String ACCOUNT_PROPERTY = "account";
	private static final String PROFILE_PROPERTY = "profile";

	/** Property key for returning a result from a child activity. */
	public static final String RESULT_PROPERTY = "result";

	private String authToken;

	private HealthGDataClient client = new HealthGDataClient(SERVICE_NAME);

	private Map<String, String> profiles = new LinkedHashMap<String, String>();

	/**
	 * Id of the currently displayed dialog used by anonymous inner classes for
	 * dismissing.
	 */
	private int dialogId;

	private Context context;

	public HealthRepository(Context context) {
		this.context = context;

		final AccountManager manager = AccountManager.get(context);
		final Account account = manager.getAccountsByType("com.google")[0];

		gotAccount(manager, account);
	}

	private void gotAccount(boolean tokenExpired) {
		SharedPreferences settings = context.getSharedPreferences(PREF, 0);
		String accountName = settings.getString(ACCOUNT_PROPERTY, null);

		if (accountName != null) {
			AccountManager manager = AccountManager.get(context);
			Account account = manager.getAccountsByType("com.google")[0];
			if (accountName.equals(account.name)) {
				if (tokenExpired) {
					manager.invalidateAuthToken("com.google", authToken);
				}
				gotAccount(manager, account);
				return;
			}
		}
		// showDialog(DIALOG_ACCOUNTS);
	}

	private void gotAccount(AccountManager manager, Account account) {
		// Store the selected account so we don't have to ask for it between app
		// restarts, unless the user wants a new one.
		SharedPreferences settings = context.getSharedPreferences(PREF, 0);
		SharedPreferences.Editor editor = settings.edit();
		editor.putString(ACCOUNT_PROPERTY, account.name);
		editor.commit();

		// Retrieve the auth token for the account.
		try {
			Bundle bundle = manager.getAuthToken(account, SERVICE_NAME, true,
					null, null).getResult();
			if (bundle.containsKey(AccountManager.KEY_INTENT)) {
				Intent intent = bundle.getParcelable(AccountManager.KEY_INTENT);
				int flags = intent.getFlags();
				flags &= ~Intent.FLAG_ACTIVITY_NEW_TASK;
				intent.setFlags(flags);
				// startActivityForResult(intent, ACTIVITY_AUTHENTICATE);
			} else if (bundle.containsKey(AccountManager.KEY_AUTHTOKEN)) {
				authToken = bundle.getString(AccountManager.KEY_AUTHTOKEN);
				client.setAuthToken(authToken);
				profiles = client.retrieveProfiles();

				String pid = profiles.keySet().toArray(
						new String[profiles.size()])[0];
				client.setProfileId(pid);
			}
		} catch (Exception e) {
			handleException(e);
			return;
		}
	}

	public Test[] GetTests() {
		
		List<Result> results = null;
		try {
			results = client.retrieveResults();
		} catch (AuthenticationException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		} catch (InvalidProfileException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}

		// Collect the Tests from the Results and order them chronologically.
		Set<Test> tests = new TreeSet<Test>(new Comparator<Test>() {
			@Override
			public int compare(Test t1, Test t2) {
				// TODO Check for null dates and names
				int x = t1.getDate().compareTo(t2.getDate());

				if (x != 0) {
					return x;
				}

				x = t1.getName().compareTo(t2.getName());

				if (x != 0) {
					return x;
				}

				return -1;
			}
		});

		for (Result result : results) {
			tests.addAll(result.getTests());

			// If the Test is missing it's date, then assign the Result date.
			for (Test test : result.getTests()) {
				if (test.getDate() == null) {
					test.setDate(result.getDate());
				}
			}
		}
		
		return tests.toArray(new Test[tests.size()]);
//		// Update the text view of the main activity with the list of test
//		// results.
//		Test[] items = tests.toArray(new Test[tests.size()]);
//		setListAdapter(new ArrayAdapter<Test>(this, R.layout.list_item, items));
//
//		ListView lv = getListView();
//		lv.setTextFilterEnabled(true);
//
//		lv.setOnItemClickListener(new OnItemClickListener() {
//			public void onItemClick(AdapterView<?> parent, View view,
//					int position, long id) {
//				Toast.makeText(getApplicationContext(),
//						((TextView) view).getText(), Toast.LENGTH_SHORT).show();
//			}
//		});
	}

	// /**
	// * Retrieve a list of test results from Health and display them in a list.
	// */
	// private void displayResults() {
	// List<Result> results;
	// try {
	// results = client.retrieveResults();
	// } catch (AuthenticationException e) {
	// gotAccount(true);
	// return;
	// } catch (InvalidProfileException e) {
	// gotAccount(true);
	// return;
	// }
	//
	// // Collect the Tests from the Results and order them chronologically.
	// Set<Test> tests = new TreeSet<Test>(new Comparator<Test>() {
	// @Override
	// public int compare(Test t1, Test t2) {
	// // TODO Check for null dates and names
	// int x = t1.getDate().compareTo(t2.getDate());
	//
	// if (x != 0) {
	// return x;
	// }
	//
	// x = t1.getName().compareTo(t2.getName());
	//
	// if (x != 0) {
	// return x;
	// }
	//
	// return -1;
	// }
	// });
	//
	// for (Result result : results) {
	// tests.addAll(result.getTests());
	//
	// // If the Test is missing it's date, then assign the Result date.
	// for (Test test : result.getTests()) {
	// if (test.getDate() == null) {
	// test.setDate(result.getDate());
	// }
	// }
	// }
	//
	// // Update the text view of the main activity with the list of test
	// results.
	// Test[] items = tests.toArray(new Test[tests.size()]);
	// setListAdapter(new ArrayAdapter<Test>(this, R.layout.list_item, items));
	//
	// ListView lv = getListView();
	// lv.setTextFilterEnabled(true);
	//
	// lv.setOnItemClickListener(new OnItemClickListener() {
	// public void onItemClick(AdapterView<?> parent, View view, int position,
	// long id) {
	// Toast.makeText(getApplicationContext(), ((TextView) view).getText(),
	// Toast.LENGTH_SHORT)
	// .show();
	// }
	// });
	// }

	private void handleException(Exception e) {
		e.printStackTrace();

		SharedPreferences settings = context.getSharedPreferences(PREF, 0);
		if (settings.getBoolean("logging", false)) {
			Log.e(LOG_TAG, e.getMessage(), e);
		}
	}

}
