package mpq.momometer.repositories;

import java.util.ArrayList;
import java.util.Date;
import java.util.Random;
import java.util.logging.Logger;

import mqp.momometer.classes.ActivityDuration;
import mqp.momometer.classes.ActivityName;
import mqp.momometer.classes.ActivityCategory;
import mqp.momometer.classes.FoodCategory;
import mqp.momometer.classes.FoodItem;
import mqp.momometer.classes.FoodData;
import mqp.momometer.classes.MealType;
import mqp.momometer.helpers.DbSqlScript;
import android.content.Context;
import android.database.Cursor;
import android.database.sqlite.SQLiteDatabase;
import android.database.sqlite.SQLiteException;

public class LookUpsDataAdapter {

	private final String DB_NAME = "momometerDb";
	
	private SQLiteDatabase database;
	private Context context;
	
	public LookUpsDataAdapter(Context context)
	{
		this.context = context;
	}
	
	public ActivityCategory[] getActivityTypes()
	{
		try {
			ArrayList<ActivityCategory> results = new ArrayList<ActivityCategory>();
			database = context.openOrCreateDatabase(DB_NAME,
					Context.MODE_PRIVATE, null);

			Cursor c = database.rawQuery("SELECT * FROM " + DbSqlScript.ACTIVITY_TYPE, null);

			if (c != null) {
				if (c.moveToFirst()) {
					do {
						int id = c.getInt(c.getColumnIndex("id"));
						String description = c.getString(c.getColumnIndex("description"));

						ActivityCategory aType = new ActivityCategory(id, description);
						results.add(aType);

					} while (c.moveToNext());
				}
			}
			database.close();

			return (ActivityCategory[]) results
					.toArray(new ActivityCategory[results.size()]);

		} catch (SQLiteException se) {

		}
		return null;
	}
	
	public ActivityName[] getActivityNamesByType(int activityType)
	{
		try {
			ArrayList<ActivityName> results = new ArrayList<ActivityName>();
			database = context.openOrCreateDatabase(DB_NAME,
					Context.MODE_PRIVATE, null);

			Cursor c = database.rawQuery("SELECT * FROM " + DbSqlScript.ACTIVITY_NAME + " where type == " + activityType, null);

			if (c != null) {
				if (c.moveToFirst()) {
					do {
						int id = c.getInt(c.getColumnIndex("id"));
						String description = c.getString(c.getColumnIndex("description"));

						ActivityName activity = new ActivityName(id, description);
						results.add(activity);

					} while (c.moveToNext());
				}
			}
			database.close();

			return (ActivityName[]) results
					.toArray(new ActivityName[results.size()]);

		} catch (SQLiteException se) {

		}
		return null;
	}
	
	public ActivityDuration[] getActivityDurations()
	{
		try {
			ArrayList<ActivityDuration> results = new ArrayList<ActivityDuration>();
			database = context.openOrCreateDatabase(DB_NAME,
					Context.MODE_PRIVATE, null);

			Cursor c = database.rawQuery("SELECT * FROM " + DbSqlScript.TIME_DURATION, null);

			if (c != null) {
				if (c.moveToFirst()) {
					do {
						int id = c.getInt(c.getColumnIndex("id"));
						String description = c.getString(c.getColumnIndex("duration"));

						ActivityDuration aDuration = new ActivityDuration(id, description);
						results.add(aDuration);

					} while (c.moveToNext());
				}
			}
			database.close();

			return (ActivityDuration[]) results
					.toArray(new ActivityDuration[results.size()]);

		} catch (SQLiteException se) {

		}
		return null;
	}
	
	public MealType[] getMealTypes()
	{
		try {
			ArrayList<MealType> results = new ArrayList<MealType>();
			database = context.openOrCreateDatabase(DB_NAME,
					Context.MODE_PRIVATE, null);

			Cursor c = database.rawQuery("SELECT * FROM " + DbSqlScript.MEAL_TYPE, null);

			if (c != null) {
				if (c.moveToFirst()) {
					do {
						int id = c.getInt(c.getColumnIndex("id"));
						String description = c.getString(c.getColumnIndex("description"));

						MealType mealType= new MealType(id, description);
						results.add(mealType);

					} while (c.moveToNext());
				}
			}
			c.close();
			database.close();

			return (MealType[]) results
					.toArray(new MealType[results.size()]);

		} catch (SQLiteException se) {

		}
		return null;
	}
	
	public FoodCategory[] getCategories()
	{
		try {
			ArrayList<FoodCategory> results = new ArrayList<FoodCategory>();
			database = context.openOrCreateDatabase(DB_NAME,
					Context.MODE_PRIVATE, null);

			Cursor c = database.rawQuery("SELECT * FROM " + DbSqlScript.FOOD_CATEGORIES, null);

			if (c != null) {
				if (c.moveToFirst()) {
					do {
						int id = c.getInt(c.getColumnIndex("id"));
						String description = c.getString(c.getColumnIndex("category"));

						FoodCategory category= new FoodCategory(id, description);
						results.add(category);

					} while (c.moveToNext());
				}
			}
			c.close();
			database.close();

			return (FoodCategory[]) results
					.toArray(new FoodCategory[results.size()]);

		} catch (SQLiteException se) {

		}
		return null;
	}
	
	public FoodItem[] getFoodsByCategory(int category)
	{
		try {
			ArrayList<FoodItem> results = new ArrayList<FoodItem>();
			database = context.openOrCreateDatabase(DB_NAME,
					Context.MODE_PRIVATE, null);

			Cursor c = database.rawQuery("SELECT * FROM " + DbSqlScript.FOOD_LIST + " where category == " + category, null);

			if (c != null) {
				if (c.moveToFirst()) {
					do {
						int id = c.getInt(c.getColumnIndex("id"));
						String name = c.getString(c.getColumnIndex("name"));
						String description = c.getString(c.getColumnIndex("description"));
						int calories = c.getInt(c.getColumnIndex("calories"));
						int image = c.getInt(c.getColumnIndex("image"));

						FoodItem food = new FoodItem(id, category, name, description, calories, image);
						results.add(food);

					} while (c.moveToNext());
				}
			}
			c.close();
			database.close();

			return (FoodItem[]) results
					.toArray(new FoodItem[results.size()]);

		} catch (SQLiteException se) {

		}
		return null;
	}
	
	/**
	 * Returns the top n foods with the most servings from the given meal type
	 * @param mealtype
	 * @return
	 */
	public FoodItem[] getCommonFoodsByMealType(int mealtype, int n)
	{
		try {
			ArrayList<FoodItem> results = new ArrayList<FoodItem>();
			database = context.openOrCreateDatabase(DB_NAME,
					Context.MODE_PRIVATE, null);

			Cursor c = database.rawQuery("SELECT name, description, category, calories, image, foodId, sum (servings) as numservings" +
					                     " FROM " + DbSqlScript.FOOD_LIST + ", " + DbSqlScript.FOOD_INPUT + 
					                     " WHERE " + DbSqlScript.FOOD_INPUT + ".foodId = " + DbSqlScript.FOOD_LIST + ".id" +
					                     " AND mealType == " + mealtype +
					                     " GROUP BY name, description, category, calories, image, foodId " +
					                     " ORDER BY numservings desc " +
					                     " LIMIT " + n, null);
			if (c != null) {
				if (c.moveToFirst()) {
					do {
						int id = c.getInt(c.getColumnIndex("foodId"));
						String name = c.getString(c.getColumnIndex("name"));
						String description = c.getString(c.getColumnIndex("description"));
						int category = c.getInt(c.getColumnIndex("category"));
						int calories = c.getInt(c.getColumnIndex("calories"));
						int image = c.getInt(c.getColumnIndex("image"));
						FoodItem food = new FoodItem(id, category, name, description, calories, image);
						//Food food = new Food(id,0,mealType,null,null,0,0,servings);
						results.add(food);

					} while (c.moveToNext());
				}
			}
			c.close();
			database.close();

			return (FoodItem[]) results
					.toArray(new FoodItem[results.size()]);

		} catch (SQLiteException se) {
			throw se;
		}
	}
	
	/**
	 * 
	 * @param context
	 * @param week
	 * @return
	 */
	public String getBabyFactByWeek(int week) {
		try {			
			Random gen = new Random();
			int randNum = gen.nextInt(3) + 1;
			database = context.openOrCreateDatabase(DB_NAME,
					Context.MODE_PRIVATE, null);

			Cursor c = database.rawQuery("SELECT * FROM " + DbSqlScript.BABY_FACTS
					+ " where week == " + week + " and number == " + randNum, null);			
			if (c != null) {
				if (c.moveToFirst()) {
					String fact = c.getString(c.getColumnIndex("description"));
						c.close();
						database.close();
						return fact;
				}
			}
			return null;
		} catch (SQLiteException se) {

		}
		return null;
	}
	
/*	*//**
	 * Get the help information string for the given screen/layout id
	 * @param screenId
	 * @return String
	 *//*
	public String getHelpInfoForScreen(int screenId)
	{
		try {			
			database = context.openOrCreateDatabase(DB_NAME,
					Context.MODE_PRIVATE, null);

			Cursor c = database.rawQuery("SELECT * FROM " + DbSqlScript.HELP_INFORMATION
					+ " where screenId == " + screenId, null);			
			if (c != null) {
				if (c.moveToFirst()) {
					String info = c.getString(c.getColumnIndex("description"));
						return info;
				}
			}
			return null;
		} catch (SQLiteException se) {

		}
		return null;
	}*/
	
	/**
	 * Get the app information string for the given screen/layout id
	 * @param screenId
	 * @return String
	 */
	public String getAppInfoForScreen(int screenId)
	{
		try {			
			database = context.openOrCreateDatabase(DB_NAME,
					Context.MODE_PRIVATE, null);

			Cursor c = database.rawQuery("SELECT * FROM " + DbSqlScript.APP_INFORMATION
					+ " where screenId == " + screenId, null);			
			if (c != null) {
				if (c.moveToFirst()) {
					String info = c.getString(c.getColumnIndex("description"));
						return info;
				}
			}
			return null;
		} catch (SQLiteException se) {

		}
		return null;	
	}
}
