package mpq.momometer.repositories;

import java.util.ArrayList;
import java.util.Date;

import mqp.momometer.classes.Day;
import mqp.momometer.classes.Reminder;
import android.content.ContentValues;
import android.content.Context;
import android.database.Cursor;
import android.database.sqlite.SQLiteDatabase;
import android.database.sqlite.SQLiteException;

public class RemindersDataAdapter {
	private final String DB_NAME = "momometerDb";
	private final String TABLE_NAME = "weightReminders";

	private SQLiteDatabase database;
	private Context context;

	private final String[] daysColumnNames = { "sunday", "monday", "tuesday",
			"wednesday", "thursday", "friday", "saturday" };
	
	private final String deleteStmt = "delete from " + TABLE_NAME + " where id == ";
	
	public RemindersDataAdapter(Context context) {
		this.context = context;
	}

	
	/**
	 * Insert the given reminder into the database
	 * @param r
	 * @return int - the id assigned to the row
	 */
	public int insertReminder(Reminder r) {
		try {
			database = context.openOrCreateDatabase(DB_NAME,
					Context.MODE_PRIVATE, null);

			Day[] selectedDays = r.getDays();
			int days[] = new int[7];

			for (int index = 0; index < selectedDays.length; index++) {
				days[selectedDays[index].getDay()] = 1;
			}

			ContentValues cv = new ContentValues();
			cv.put("type", r.getType());
			cv.put("hour", r.getTime().getHours());
			cv.put("minute", r.getTime().getMinutes());
			
			for (int i =0; i < 7; i++)
			{
				cv.put(daysColumnNames[i], days[i]);
			}
			
			int rowId = (int) database.insert(TABLE_NAME, null, cv);
			database.close();
			return rowId;
		} catch (SQLiteException se) {
			return -1;
		}
	}
	
	
	/**
	 * Delete the given reminder from the database
	 * @param r
	 * @return boolean - true if successful
	 */
	public boolean deleteReminder(Reminder r)
	{
		try {
			database = context.openOrCreateDatabase(DB_NAME,
					Context.MODE_PRIVATE, null);			
			database.execSQL(deleteStmt + r.getId());
			database.close();
			return true;
		} catch (SQLiteException se) {
			return false;
		}
	}
	
	/**
	 * Update the given reminder
	 * @param r
	 * @return boolean - true if successful
	 */
	public boolean updateReminder(Reminder r)
	{
		try
		{
			database = context.openOrCreateDatabase(DB_NAME,
					Context.MODE_PRIVATE, null);

			Day[] selectedDays = r.getDays();
			int days[] = new int[7];

			for (int index = 0; index < selectedDays.length; index++) {
				days[selectedDays[index].getDay()] = 1;
			}

			database.execSQL("update " + TABLE_NAME + " set hour = " + r.getTime().getHours() + ", minute = " + r.getTime().getMinutes() + ", " + 
															daysColumnNames[0] + "=" + days[0] + ", " + daysColumnNames[1] + "=" + days[1] + ", " + 
															daysColumnNames[2] + "=" + days[2] + ", " + daysColumnNames[3] + "=" + days[3] + ", " + 
															daysColumnNames[4] + "=" + days[4] + ", " + daysColumnNames[5] + "=" + days[5] + ", " + 
															daysColumnNames[6] + "=" + days[6] + " where id == " + r.getId());
			database.close();
			return true;
		}
		catch (SQLiteException se)
		{
			return false;
		}
	}
	
	
	/**
	 * Return the reminder with the given id from the database
	 * @param id 
	 * @return Reminder
	 */
	public Reminder getReminderById(int id)
	{
		try
		{
			database = context.openOrCreateDatabase(DB_NAME, Context.MODE_PRIVATE,
					null);

			Cursor c = database.rawQuery("SELECT * FROM " + TABLE_NAME
					+ " where id == " + id, null);
			
			if (c!= null)
			{
				if (c.moveToFirst())
				{
					int type = c.getInt(c.getColumnIndex("type"));
					Date t = new Date();
					t.setHours(c.getInt(c.getColumnIndex("hour")));
					t.setMinutes(c.getInt(c.getColumnIndex("minute")));
					ArrayList<Day> selectedDays = new ArrayList<Day>();

					for (int index = 0; index < 7; index++) {
						if (c.getInt(c.getColumnIndex(daysColumnNames[index])) == 1) {
							selectedDays.add(new Day(index));
						}
					}

					return new Reminder(id,type,
									(Day[]) selectedDays.toArray(new Day[selectedDays
									.size()]), t);
				}
			}
			// No reminder with given id found
			return null;
		}
		catch (SQLiteException se)
		{
			
		}
		return null;
	}
	
	/**
	 * Get all reminders of the given type
	 * @param type
	 * @return Reminder[] - Array of reminders
	 */
	public Reminder[] getReminders(int type) {
		database = context.openOrCreateDatabase(DB_NAME, Context.MODE_PRIVATE,
				null);
		ArrayList<Reminder> results = new ArrayList<Reminder>();

		Cursor c = database.rawQuery("SELECT * FROM " + TABLE_NAME
				+ " where type == " + type, null);

		if (c != null) {
			if (c.moveToFirst()) {
				do {
					int id = c.getInt(c.getColumnIndex("id"));
					Date t = new Date();
					t.setHours(c.getInt(c.getColumnIndex("hour")));
					t.setMinutes(c.getInt(c.getColumnIndex("minute")));
					ArrayList<Day> selectedDays = new ArrayList<Day>();

					for (int index = 0; index < 7; index++) {
						if (c.getInt(c.getColumnIndex(daysColumnNames[index])) == 1) {
							selectedDays.add(new Day(index));
						}
					}

					results.add(new Reminder(id,type,
									(Day[]) selectedDays.toArray(new Day[selectedDays
									.size()]), t));
				} while (c.moveToNext());
			}
		}
		database.close();
		return (Reminder[]) results.toArray(new Reminder[results.size()]);
	}
}
