package mpq.momometer.repositories;

import java.util.Date;

import android.content.Context;
import android.content.SharedPreferences;

public class SharedPreferencesAdapter {

	public static final String PREF = "MomometerPrefs";
	
	private static final String STARTING_WEEK = "startingWeek";
	private static final String STARTING_WEIGHT = "startingWeight";
	private static final String STARTING_HEIGHTFEET = "startingHeightFeet";
	private static final String STARTING_HEIGHTINCHES = "startingHeightInches";
	private static final String DB_SETUP = "dbSetup";
	private static final String STARTING_DATE = "startingDate";
	private static final String APP_REMINDER_SETUP = "appReminderSetup";
	private static final String CURRENT_DAY = "currentDay";	
	private static final String ACCOUNT_PROPERTY = "account";
	private static final String PROFILE_PROPERTY = "profile";

	/**
	 * Returns the starting week of the pregnancy
	 * 
	 * @param context
	 * @return int
	 */
	public static int getStartingWeek(Context context) {
		SharedPreferences settings = context.getSharedPreferences(PREF, 0);
		int startingPregnancyWeek = settings.getInt(STARTING_WEEK, -1);
		return startingPregnancyWeek;
	}
	
	/**
	 * 
	 * @param context
	 * @return
	 */
	public static float getStartingWeight(Context context) {
		SharedPreferences settings = context.getSharedPreferences(PREF, 0);
		float startingWeight = settings.getFloat(STARTING_WEIGHT, -1);
		return startingWeight;
	}

	/**
	 * 
	 * @param context
	 * @return
	 */
	public static int getStartingHeightFeet(Context context) {
		SharedPreferences settings = context.getSharedPreferences(PREF, 0);
		int startingHeight = settings.getInt(STARTING_HEIGHTFEET, -1);
		return startingHeight;
	}
	
	/**
	 * 
	 * @param context
	 * @return
	 */
	public static int getStartingHeightInches(Context context) {
		SharedPreferences settings = context.getSharedPreferences(PREF, 0);
		int startingHeight = settings.getInt(STARTING_HEIGHTINCHES, -1);
		return startingHeight;
	}	
	
	/**
	 * Returns a boolean
	 * 
	 * @param context
	 * @return boolean
	 */
	public static boolean isDbSetup(Context context) {
		SharedPreferences settings = context.getSharedPreferences(PREF, 0);
		boolean databaseSetup = settings.getBoolean(DB_SETUP, false);
		return databaseSetup;
	}

	/**
	 * 
	 * @param context
	 * @return
	 */
	public static Date getStartTimestamp(Context context) {
		SharedPreferences settings = context.getSharedPreferences(PREF, 0);
		String startingTimestamp = settings
				.getString(STARTING_DATE, null);
		return new Date(startingTimestamp);
	}

	/**
	 * 
	 * @param context
	 */
	public static boolean dbIsSetup(Context context) {
		SharedPreferences settings = context.getSharedPreferences(PREF, 0);
		SharedPreferences.Editor editor = settings.edit();
		editor.putBoolean(DB_SETUP, true);
		return editor.commit();

	}

	/**
	 * 
	 * @param context
	 * @param week
	 */
	public static boolean setStartingWeek(Context context, int week) {
		SharedPreferences settings = context.getSharedPreferences(PREF, 0);
		SharedPreferences.Editor editor = settings.edit();
		editor.putInt(STARTING_WEEK, week);
		return editor.commit();
	}

	/**
	 * 
	 * @param context
	 * @param timestamp
	 */
	public static boolean setStartTimestamp(Context context, String timestamp) {
		SharedPreferences settings = context.getSharedPreferences(PREF, 0);
		SharedPreferences.Editor editor = settings.edit();
		editor.putString(STARTING_DATE, timestamp);
		return editor.commit();
	}
	
	/**
	 * 
	 * @param context
	 * @param timestamp
	 */
	public static boolean setStartingWeight(Context context, float weight) {
		SharedPreferences settings = context.getSharedPreferences(PREF, 0);
		SharedPreferences.Editor editor = settings.edit();
		editor.putFloat(STARTING_WEIGHT, weight);
		return editor.commit();
	}

	/**
	 * 
	 * @param context
	 * @param timestamp
	 */
	public static boolean setStartingHeightFeet(Context context, int height) {
		SharedPreferences settings = context.getSharedPreferences(PREF, 0);
		SharedPreferences.Editor editor = settings.edit();
		editor.putInt(STARTING_HEIGHTFEET, height);
		return editor.commit();
	}
	
	/**
	 * 
	 * @param context
	 * @param timestamp
	 */
	public static boolean setStartingHeightInches(Context context, int height) {
		SharedPreferences settings = context.getSharedPreferences(PREF, 0);
		SharedPreferences.Editor editor = settings.edit();
		editor.putInt(STARTING_HEIGHTINCHES, height);
		return editor.commit();
	}
	
	/**
	 * 
	 * @param context
	 * @return
	 */
	public static boolean isAppReminderSetup(Context context) {
		SharedPreferences settings = context.getSharedPreferences(PREF, 0);
		boolean appReminderSetup = settings.getBoolean(APP_REMINDER_SETUP,
				false);
		return appReminderSetup;
	}

	/**
	 * 
	 * @param context
	 * @return
	 */
	public static boolean appReminderIsSetup(Context context) {
		SharedPreferences settings = context.getSharedPreferences(PREF, 0);
		SharedPreferences.Editor editor = settings.edit();
		editor.putBoolean(APP_REMINDER_SETUP, true);
		return editor.commit();
	}

	/**
	 * 
	 * @param context
	 * @return
	 */
	public static int getCurrentDay(Context context) {
		SharedPreferences settings = context.getSharedPreferences(PREF, 0);
		int currentDay = settings.getInt(CURRENT_DAY, -1);
		return currentDay;
	}

	/**
	 * 
	 * @param context
	 * @param daysToAdd
	 * @return
	 */
	public static boolean updateCurrentDay(Context context, int daysToAdd) {
		SharedPreferences settings = context.getSharedPreferences(PREF, 0);
		int currentDay = settings.getInt(CURRENT_DAY, -1);

		SharedPreferences.Editor editor = settings.edit();
		editor.putInt("currentDay", currentDay + daysToAdd);
		return editor.commit();
	}
	
	/**
	 * 
	 * @param context
	 * @param accountName
	 * @return
	 */
	public static boolean setGHealthAccount(Context context, String accountName)
	{
		SharedPreferences settings = context.getSharedPreferences(PREF, 0);
		SharedPreferences.Editor editor = settings.edit();
		editor.putString(ACCOUNT_PROPERTY, accountName);
		return editor.commit();
	}
	
	/**
	 * 
	 * @param context
	 * @return
	 */
	public static String getGHealthAccountName(Context context)
	{
		SharedPreferences settings = context.getSharedPreferences(PREF, 0);
		String accountName = settings.getString(ACCOUNT_PROPERTY, null);
		return accountName;
	}

	/**
	 * 
	 * @param context
	 * @param profileId
	 * @return
	 */
	public static boolean setGHealthProfile(Context context, String profileId)
	{
		SharedPreferences settings = context.getSharedPreferences(PREF, 0);
		SharedPreferences.Editor editor = settings.edit();
		editor.putString(PROFILE_PROPERTY, profileId);
		return editor.commit();
	}
	
	/**
	 * 
	 * @param context
	 * @return
	 */
	public static String getGHealthProfile(Context context)
	{
		SharedPreferences settings = context.getSharedPreferences(PREF, 0);
		String profileId = settings.getString(PROFILE_PROPERTY, null);
		return profileId;
	}
	
}
