package mpq.momometer.repositories;

import java.util.ArrayList;
import java.util.Date;

import mqp.momometer.classes.FoodDataPoint;
import mqp.momometer.classes.FoodDataPointSet;
import mqp.momometer.classes.WeightData;
import mqp.momometer.helpers.DbSqlScript;
import mqp.momometer.helpers.HelperFunctions;
import android.content.Context;
import android.database.Cursor;
import android.database.sqlite.SQLiteDatabase;
import android.database.sqlite.SQLiteException;

public class WeightDataAdapter {

	private final String DB_NAME = "momometerDb";
	private final String TABLE_NAME = DbSqlScript.WEIGHT_INPUT;

	private SQLiteDatabase database;
	private Context context;

	private final String insertStmt = "insert into " + TABLE_NAME
			+ "(weight, type, timestamp, week) values(";

	private final String deleteStmt = "delete from " + TABLE_NAME
			+ " where id == ";

	public WeightDataAdapter(Context context) {
		this.context = context;
	}
	
	/**
	 * Store the given weight data in the database
	 * @param weight
	 */
	public boolean insertWeightData(WeightData weight) {
		try {
			database = context.openOrCreateDatabase(DB_NAME,
					Context.MODE_PRIVATE, null);
			database.execSQL((insertStmt + weight.getWeight() + ","
					+ weight.getMeasurementType() + ",'" 
					+ HelperFunctions.getTimeStampString() + "'," 
					+ HelperFunctions.getCurrentWeek(context) + ")"));
			database.close();
			return true;
		} catch (SQLiteException se) {
			return false;
		}
	}

	public void updateWeightData(WeightData weight) {
		try {
			database = context.openOrCreateDatabase(DB_NAME,
					Context.MODE_PRIVATE, null);

			database.execSQL("update " + TABLE_NAME + " set weight = "
					+ weight.getWeight() + ", type = "
					+ weight.getMeasurementType() + " where id == "
					+ weight.getId());
			database.close();
		} catch (SQLiteException se) {

		}
	}

	public WeightData[] getWeightData() {
		try {
			ArrayList<WeightData> results = new ArrayList<WeightData>();
			database = context.openOrCreateDatabase(DB_NAME,
					Context.MODE_PRIVATE, null);

			Cursor c = database.rawQuery("SELECT * FROM " + TABLE_NAME, null);

			if (c != null) {
				if (c.moveToFirst()) {
					do {
						int id = c.getInt(c.getColumnIndex("id"));
						double weightData = c.getDouble(c
								.getColumnIndex("weight"));
						int type = c.getInt(c.getColumnIndex("type"));
						Date timestamp = new Date(c.getString(c.getColumnIndex("timestamp")));
						int week = c.getInt(c.getColumnIndex("week"));
						WeightData w = new WeightData(id, weightData, type, timestamp, week);
						results.add(w);

					} while (c.moveToNext());
				}
			}
			c.close();			
			database.close();

			return (WeightData[]) results
					.toArray(new WeightData[results.size()]);

		} catch (SQLiteException se) {

		}
		return null;
	}
	
	public FoodDataPointSet getWeightDataPointsByWeek()
	{
		try {
		FoodDataPointSet results = new FoodDataPointSet();
		database = context.openOrCreateDatabase(DB_NAME,
				Context.MODE_PRIVATE, null);
		
		Cursor c = database.rawQuery("SELECT avg(weight) as avgwgt, week " +
				 " FROM " + DbSqlScript.WEIGHT_INPUT +			            
                " GROUP BY week" , null);
		
		if (c != null) {
			if (c.moveToFirst()) {
				do {
					int weight = c.getInt(c.getColumnIndex("avgwgt"));
					int timeunit = c.getInt(c.getColumnIndex("week"));
					FoodDataPoint dp = new FoodDataPoint(timeunit,weight, 0);	
					
					results.put(dp);

				} while (c.moveToNext());
			}
		}
		
		c.close();
		database.close();

		return results;
		}
		catch (SQLiteException se) {

		}
		return null;
	}
	
	public double getWeightByWeek(int week)
	{
		try {
			database = context.openOrCreateDatabase(DB_NAME,
					Context.MODE_PRIVATE, null);
			
			Cursor c = database.rawQuery("SELECT avg(weight) as avgwgt, week " +
					 " FROM " + DbSqlScript.WEIGHT_INPUT +			            
	                " WHERE week = " + week , null);
			

			if (c != null) {
				if (c.moveToFirst()) {
					do {
						double weight = c.getFloat(c.getColumnIndex("avgwgt"));
						
						// Close connections and return data 
						c.close();
						database.close();
						return weight;

					} while (c.moveToNext());
				}
			}
		}
		catch (SQLiteException se) {

		}
		return 0;
	}

	public WeightData getWeightById(int id) {
		try {
			database = context.openOrCreateDatabase(DB_NAME,
					Context.MODE_PRIVATE, null);

			Cursor c = database.rawQuery("SELECT * FROM " + TABLE_NAME
					+ " where id == " + id, null);

			if (c != null) {
				if (c.moveToFirst()) {
					double weightData = c.getDouble(c.getColumnIndex("weight"));
					int type = c.getInt(c.getColumnIndex("type"));
					Date timestamp = new Date(c.getString(c.getColumnIndex("timestamp")));
					int week = c.getInt(c.getColumnIndex("week"));
					
					// Close all connections
					c.close();
					database.close();
					
					return new WeightData(id, weightData, type, timestamp, week);
				}
			}
			// No weight with given id found
			return null;
		} catch (SQLiteException se) {

		}
		return null;
	}

	public void deleteWeight(WeightData w) {
		try {
			database = context.openOrCreateDatabase(DB_NAME,
					Context.MODE_PRIVATE, null);
			database.execSQL(deleteStmt + w.getId());
			database.close();
		} catch (SQLiteException se) {
		}
	}
}
