package mqp.momometer;

import mpq.momometer.repositories.ActivityDataAdapter;
import mpq.momometer.repositories.LookUpsDataAdapter;
import mqp.momometer.alarms.NotificationController;
import mqp.momometer.classes.ActivityData;
import mqp.momometer.classes.ActivityDuration;
import mqp.momometer.classes.ActivityName;
import mqp.momometer.classes.ActivityCategory;
import mqp.momometer.classes.ActivityType;
import mqp.momometer.helpers.DialogHandler;
import android.app.Activity;
import android.app.Dialog;
import android.content.DialogInterface;
import android.content.Intent;
import android.content.DialogInterface.OnClickListener;
import android.os.Bundle;
import android.view.View;
import android.widget.Button;

public class ActivityInputActivity extends Activity {
		
	// Dialog window properties
	private ActivityCategory[] activityTypeListItems;
	private ActivityName[] activityListItems;
	private ActivityDuration[] durationListItems;
	private CharSequence[] selectListItems; 
	
	private ActivityData activity;
	private LookUpsDataAdapter lookUpAdapter;
	
	public void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.activitytrackinginput);
		
		lookUpAdapter = new LookUpsDataAdapter(this);
		activityTypeListItems = lookUpAdapter.getActivityTypes();
		
		activity = new ActivityData();
	}

	public void btnMenuHandler(View view) {
				
		int id = view.getId();
		OnClickListener listener;
		Dialog myDialog = null;
		
		switch (id) {
		case R.id.btnActivityTypeInput:
			selectListItems = new CharSequence[activityTypeListItems.length];
			for (int i = 0; i < activityTypeListItems.length; i++)
			{
				selectListItems[i] = activityTypeListItems[i].getName();
			}
			
			listener = new OnClickListener() {
				
				@Override
				public void onClick(DialogInterface dialog, int which) {
					// TODO Auto-generated method stub
					Button btn = (Button)findViewById(R.id.btnActivityTypeInput);
					btn.setText(activityTypeListItems[which].getName());
					activity.setType(activityTypeListItems[which].getId());
				}
			};
			myDialog = DialogHandler.createSingleSelectionDialog("Select an activity type",selectListItems, this, listener);			
			break;
		
		case R.id.btnActivityNameInput:			
			// Get selected activity type
			int selectedActivityType = activity.getType();
			
			if (selectedActivityType != 0)
			{
			//Populate list of items for the dialog		
			activityListItems = lookUpAdapter.getActivityNamesByType(selectedActivityType);		
			
			// Set the select list for the dialog
			selectListItems = new CharSequence[activityListItems.length];
			for (int i = 0; i < activityListItems.length; i++)
			{
				selectListItems[i] = activityListItems[i].getName();
			}
			
			// Code that will execute when the user selects an item
			listener = new OnClickListener(){

				@Override
				public void onClick(DialogInterface dialog, int item) {
					Button btn = (Button)findViewById(R.id.btnActivityNameInput);
					btn.setText(activityListItems[item].getName());
					activity.setActivity(activityListItems[item].getId());					
				}
				
			};
			myDialog = DialogHandler.createSingleSelectionDialog("Select an activity",selectListItems, this, listener);
			}
			else
			{
				DialogHandler.toastNotify(this, "Please select an activity type first.");
			}
			break;
		
		case R.id.btnActivityDurationInput:
			durationListItems = lookUpAdapter.getActivityDurations();
			
			// Set the select list for the dialog			
			selectListItems = new CharSequence[durationListItems.length];
			for (int i = 0; i < durationListItems.length; i++)
			{
				selectListItems[i] = durationListItems[i].getDuration();
			}
			
			listener = new OnClickListener(){

				@Override
				public void onClick(DialogInterface dialog, int item) {
					// TODO Auto-generated method stub
					// WIP - this is the part that is executed when the user
					// clicks an item.
					Button btn = (Button)findViewById(R.id.btnActivityDurationInput);
					btn.setText(durationListItems[item].getDuration());
					activity.setDuration(durationListItems[item].getId());
				}				
			};
			myDialog = DialogHandler.createSingleSelectionDialog("Select a duration",selectListItems, this, listener);
			break;
			
		case R.id.btnActivityEnter:

			if (activity.getType() == 0)
			{
				DialogHandler.toastNotify(this, "Please select an activity type");
				return;		
			}			
			// Check that user has selected an activity and a duration
			else if (activity.getActivity() == 0)
			{
				DialogHandler.toastNotify(this, "Please select an activity");
				return;				
			}
			else if (activity.getDuration() == 0)
			{
				DialogHandler.toastNotify(this, "Please select a duration");
				return;
			}
					
			ActivityDataAdapter adapter = new ActivityDataAdapter(this);
			
			if (adapter.insertActivityData(activity))
			{
				DialogHandler.toastNotify(this, "Your activity has been recorded.");
				NotificationController.RemoveNotification(this, ActivityType.ACTIVITYTRACKING);
				
				// Navigate back to activity tracking screen
				startActivity(new Intent(this,TabFactoryActivity.class).putExtra("Activity", ActivityType.ACTIVITYTRACKING));
			}
			else
			{
				DialogHandler.toastNotify(this, "Your input could not be recorded. Please try again.");
			}
			
			break;
		
		case R.id.btnActivityCancel:
			// Navigate back to activity tracking screen
			startActivity(new Intent(this,TabFactoryActivity.class).putExtra("Activity", ActivityType.ACTIVITYTRACKING));
		}
		
		if (myDialog != null) myDialog.show();
	}
}
