package mqp.momometer;

import java.text.SimpleDateFormat;
import java.util.Date;

import mpq.momometer.repositories.RemindersDataAdapter;
import mqp.momometer.adapters.DaysListAdapter;
import mqp.momometer.alarms.AlarmController;
import mqp.momometer.classes.ActivityType;
import mqp.momometer.classes.Day;
import mqp.momometer.classes.Reminder;
import mqp.momometer.helpers.ActivityTitleGenerator;
import mqp.momometer.helpers.DialogHandler;
import android.app.Activity;
import android.app.Dialog;
import android.app.TimePickerDialog.OnTimeSetListener;
import android.content.Intent;
import android.os.Bundle;
import android.view.View;
import android.widget.ListView;
import android.widget.TextView;
import android.widget.TimePicker;

/**
 * This activity 
 * @author WindowsU
 *
 */
public class AddReminderActivity extends Activity {

	private DaysListAdapter mAdapter;
	private ListView daysList;
	private Date selectedTime;
	private int activityType;

	private int currentReminderId;

	public void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.addreminder);
		activityType = this.getIntent().getExtras().getInt("activity");
		//Generates Header title on Add Reminder Setting
		TextView lblReminderHeader = (TextView)findViewById(R.id.idLblAddReminderTitle);
		String headerTitle = ActivityTitleGenerator.GetActivityTitleFromActivity(this, activityType);
		lblReminderHeader.setText(headerTitle);
		
		/* If edit mode */
		currentReminderId = this.getIntent().getExtras().getInt("reminderId");
		Day[] selectedDays = null;

		if (currentReminderId != 0) {
			RemindersDataAdapter adapter = new RemindersDataAdapter(this);
			Reminder currentReminder = adapter
					.getReminderById(currentReminderId);

			TextView txt = (TextView) findViewById(R.id.btnWeightReminderSelectTime);
			txt.setText(currentReminder.getTimeString());

			selectedDays = currentReminder.getDays();
			selectedTime = currentReminder.getTime();
		}

		// Initialize the list adapter
		mAdapter = new DaysListAdapter(this, selectedDays);

		// Prepare the list by setting the adapter
		daysList = (ListView) findViewById(R.id.lstSelectedReminderDays);
		daysList.setAdapter(mAdapter);
		daysList.setChoiceMode(ListView.CHOICE_MODE_MULTIPLE);
	}

	public void btnMenuHandler(View view) {

		int id = view.getId();
		switch (id) {
		case R.id.btnWeightReminderSelectTime:
			OnTimeSetListener listener = new OnTimeSetListener() {

				@Override
				public void onTimeSet(TimePicker view, int hourOfDay, int minute) {
					TextView txt = (TextView) findViewById(R.id.btnWeightReminderSelectTime);
					selectedTime = new Date(0, 0, 0, hourOfDay, minute);
					SimpleDateFormat formatter = new SimpleDateFormat("h:mm a");
					txt.setText(formatter.format(selectedTime));
				}

			};
			Dialog myTimeDialog = DialogHandler.createTimePickerDialog(this,
					listener, 0, 0, false);
			myTimeDialog.show();
			break;

		case R.id.btnAddReminderOk:
			
			if (selectedTime != null)
			{
			RemindersDataAdapter adapter = new RemindersDataAdapter(this);
			Reminder old_reminder = adapter.getReminderById(currentReminderId);
			
			Day[] selectedDays = mAdapter.getSelectedDays();					
			Reminder r = new Reminder(currentReminderId, activityType,
					selectedDays, selectedTime);			

			if (currentReminderId != 0) {
				// Update the reminder
				if (adapter.updateReminder(r)) {
					AlarmController.DeleteReminder(this, old_reminder);
					AlarmController.AddNewReminder(this, r);
					DialogHandler
							.toastNotify(this, "Reminder has been updated");
				}				
			} else {
				// Store reminder to database
				int rowId = adapter.insertReminder(r);
				if (rowId != -1) {
					// Set the unique id returned by the database
					r.setId(rowId);
					AlarmController.AddNewReminder(this, r);
					DialogHandler.toastNotify(this, "New reminder added");
				}
			}

			// Navigate back to reminders screen
			startActivity(new Intent(this, TabFactoryActivity.class).putExtra(
					"Activity", ActivityType.REMINDERSETTINGS));
			}
			else
			{
				DialogHandler.toastNotify(this, "Please select a time before proceeding");
			}
			break;
		}
	}
}
