package mqp.momometer;

import mpq.momometer.repositories.FoodDataAdapter;
import mqp.momometer.classes.FoodDataPoint;
import mqp.momometer.classes.FoodDataPointSet;
import mqp.momometer.classes.FoodItem;
import mqp.momometer.classes.FoodData;
import mqp.momometer.helpers.DialogHandler;
import mqp.momometer.helpers.GraphDrawer;
import mqp.momometer.helpers.HelperFunctions;
import android.app.Activity;
import android.app.Dialog;
import android.content.DialogInterface;
import android.content.DialogInterface.OnClickListener;
import android.graphics.Bitmap;
import android.graphics.Bitmap.Config;
import android.net.ConnectivityManager;
import android.net.NetworkInfo;
import android.os.Bundle;
import android.view.View;
import android.view.ViewGroup.LayoutParams;
import android.webkit.WebView;
import android.widget.Button;
import android.widget.ImageView;

public class FoodDetailsActivity extends Activity{
	
	FoodDataAdapter foodDataAdapter;
	
	public void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.foodtrackingdetail);			
	}
	
	public void btnClickHandler(View v) {
		final CharSequence[] selectListItems;
		OnClickListener listener;

		switch (v.getId()) {
		case R.id.btnDetailSelectionTimeFrame:

			int currentWeek = HelperFunctions.getCurrentWeek(this);
			selectListItems = new CharSequence[currentWeek+1];
			selectListItems[0] = "All Weeks";
			
			for (int i = 1; i <= currentWeek; i++)
			{
				selectListItems[i] = String.valueOf("Week " + i);
			}

			listener = new OnClickListener() {
				@Override
				public void onClick(DialogInterface dialog, int item) {
					Button btn = (Button) findViewById(R.id.btnDetailSelectionTimeFrame);
					btn.setText(selectListItems[item].toString());
					
					// Generate graph
					GenerateGraph(item);
				}
			};

			Dialog timeFrameDialog = DialogHandler.createSingleSelectionDialog(
					"Select a time frame", selectListItems, this, listener);
			timeFrameDialog.show();
			break;
		}
	}
	
	public void GenerateGraph(int week)
	{		
		/* this code will be used once the FoodDataAdapter puts pregnancy week into FoodData * 
		******************************************************************************************/ 
		FoodDataAdapter adapter = new FoodDataAdapter(this);
		FoodDataPointSet dataPoints = adapter.getFoodDataPoints(week);		
		
		/* check that there is Internet connectivity */
		ConnectivityManager cm = (ConnectivityManager) getSystemService(CONNECTIVITY_SERVICE);
		NetworkInfo network = cm.getActiveNetworkInfo();

		if (network.isAvailable() && network != null) {
			WebView chartView = (WebView)findViewById(R.id.foodtrackingdetailwebview);
			
			String chartTitle;
			String dataset = dataPoints.GetXValuesSeparatedByComma() + "|" + dataPoints.GetYValuesSeparatedByComma();
			String lowestY = String.valueOf(dataPoints.GetLowestYValue());
			String highestY = String.valueOf(dataPoints.GetHighestYValue()+100);
			String lowestX = "1";
			String highestX; 
			
			// Check whether use select a single week or all weeks 
			if (week != 0)
			{
				chartTitle = "Average+Calorie+Consumption+by+Day";
				highestX = "7";
			}
			else
			{
				chartTitle = "Average+Daily+Consumption+by+Week";
				int currentWeek = HelperFunctions.getCurrentWeek(this);
				if (currentWeek < 7)
				{
					highestX = "7";
				}
				else
				{
					highestX = String.valueOf(currentWeek);
				}
			}
			
			/* construct url to call google api chart */
			String url = "http://chart.apis.google.com/chart"
				   + "?chxl=1:|Day|3:|Calories"
				   + "&chxr=0,"+ lowestX + "," + highestX + "|2,"+ lowestY +"," + highestY
				   + "&chxt=x,r,y,t"
				   + "&chs=340x200"
				   + "&chco=76A4FB" 
				   + "&cht=lxy"
				   + "&chds="+ lowestX +"," + highestX +","+ lowestY +"," + highestY
				   + "&chd=t:" + dataset
				   + "&chls=1"
				   + "&chma=5"
				   + "&chtt=" + chartTitle;
			
			chartView.loadUrl(url);
		}
		/*else {
		
		*//*********************************************************************************//*
        ImageView image = (ImageView) findViewById(R.id.imgFoodDetailsGraph);
     
        DataPoint[] dataPoints = new DataPoint [10];
        for(int i =0;i< dataPoints.length;i++)
        	dataPoints[i]= new DataPoint( i*3, 2000 + (i*i*5) + i*50);
        
        
        Bitmap emptyBmap = Bitmap.createBitmap(250,
                200, Config.ARGB_8888);
        
        int width =  emptyBmap.getWidth();
        int height = emptyBmap.getHeight();
        Bitmap charty = Bitmap.createBitmap(width, height, Bitmap.Config.ARGB_8888);
        
        charty = GraphDrawer.lineGraph(this, "Calories over Time", "Cal", emptyBmap, dataPoints);
       
        image.setImageBitmap(charty);      
		}*/
	}
}


