package mqp.momometer;

import mpq.momometer.repositories.FoodDataAdapter;
import mpq.momometer.repositories.LookUpsDataAdapter;
import mqp.momometer.R;
import mqp.momometer.TabFactoryActivity;
import mqp.momometer.adapters.FoodCommonListAdapter;
import mqp.momometer.adapters.FoodImageAdapter;
import mqp.momometer.adapters.FoodInputListAdapter;
import mqp.momometer.adapters.RemindersListAdapter;
import mqp.momometer.alarms.AlarmController;
import mqp.momometer.alarms.NotificationController;
import mqp.momometer.classes.ActivityType;
import mqp.momometer.classes.FoodCategory;
import mqp.momometer.classes.FoodItem;
import mqp.momometer.classes.FoodType;
import mqp.momometer.classes.Reminder;
import mqp.momometer.dialogs.FoodGalleryDialog;
import mqp.momometer.dialogs.FoodInfoInputDialog;
import mqp.momometer.helpers.DialogHandler;
import android.app.Activity;
import android.app.Dialog;
import android.content.Context;
import android.content.DialogInterface;
import android.content.Intent;
import android.content.DialogInterface.OnClickListener;
import android.os.Bundle;
import android.view.ContextMenu;
import android.view.MenuItem;
import android.view.View;
import android.view.ContextMenu.ContextMenuInfo;
import android.view.View.OnCreateContextMenuListener;
import android.widget.AdapterView;
import android.widget.Button;
import android.widget.GridView;
import android.widget.ListView;
import android.widget.AdapterView.AdapterContextMenuInfo;
import android.widget.AdapterView.OnItemClickListener;

public class FoodInputActivityContinued extends Activity {
	// Dialog window properties
	private int mealType;
	private Context context = this;
	private FoodInputListAdapter adapter;
	private LookUpsDataAdapter lookUpAdapter;
	private FoodDataAdapter foodInputAdapter;
	private ListView listView;

	protected static final int CONTEXTMENU_EDITITEM = 100;
	protected static final int CONTEXTMENU_DELETEITEM = 101;

	public void onCreate(Bundle savedInstanceState) {
		adapter = new FoodInputListAdapter(this);
		super.onCreate(savedInstanceState);
		setContentView(R.layout.foodtrackinginputcontinued);
		mealType = this.getIntent().getExtras().getInt("mealType");
		listView = (ListView) findViewById(R.id.lstFoodInputList);
		listView.setAdapter(adapter);
		listView.setOnCreateContextMenuListener(new OnCreateContextMenuListener() {

			@Override
			public void onCreateContextMenu(ContextMenu menu, View v,
					ContextMenuInfo menuInfo) {
				// TODO Auto-generated method stub
				menu.setHeaderTitle("Select an option");
				// menu.add(0, CONTEXTMENU_EDITITEM, 0, "Edit Reminder");
				menu.add(0, CONTEXTMENU_DELETEITEM, 1, "Delete Food");
			}
		});

		lookUpAdapter = new LookUpsDataAdapter(this);
		foodInputAdapter = new FoodDataAdapter(this);
	}

	public void btnFoodHandler(View view) {

		int id = view.getId();
		// FoodCommonListAdapter adapter = new FoodCommonListAdapter(this);
		switch (id) {

		case R.id.btnFoodAdd:

			final FoodItem[] commonFood = lookUpAdapter.getCommonFoodsByMealType(mealType, 10);
			
			// Check if user has inputed food before
			if (commonFood.length > 0) {
				CharSequence[] commonFoodStringList = new CharSequence[commonFood.length];
				for (int i = 0; i < commonFood.length; i++) {
					commonFoodStringList[i] = commonFood[i].name;
				}

				OnClickListener commonFoodClickListener = new OnClickListener() {

					@Override
					public void onClick(DialogInterface dialog, int item) {
						// TODO Auto-generated method stub
						// WIP - this is the part that is executed when the user
						// clicks an item.
						// adapter.
						FoodItem f = commonFood[item];

						FoodInfoInputDialog foodInfoInputDialog = new FoodInfoInputDialog(
								context, f, adapter);
						foodInfoInputDialog.show();
					}
				};

				OnClickListener moreFoodsClicklistener = new OnClickListener() {

					@Override
					public void onClick(DialogInterface dialog, int which) {
						// TODO Auto-generated method stub
						ShowCategoriesDialog();
					}
				};

				DialogHandler.createCommonFoodDialog("Common Food",
						commonFoodStringList, this, commonFoodClickListener,
						moreFoodsClicklistener).show();
			} else {
				ShowCategoriesDialog();
			}
			break;

		case R.id.btnFoodCommonMore:
			// for some reason the app jumps back to the overview page.
			setContentView(R.layout.foodcategories);
			break;

		case R.id.btnFoodBack:
			finish();
			break;
		case R.id.btnFoodEnter:
			FoodItem[] selectedFood = adapter.getSelectedFood();

			// Check that user has selected at least one food before proceeding
			if (selectedFood.length == 0) {
				DialogHandler
						.toastNotify(this,
								"You must add at least one food item to the list before submitting.");
				return;
			}

			// Remove food input notifications
			if (foodInputAdapter.insertFoods(selectedFood, mealType)) {
				NotificationController.RemoveNotification(this,
						ActivityType.FOODTRACKING);
				DialogHandler.toastNotify(this,
						"Your food data has been recorded!");
				finish();
			} else {
				DialogHandler.toastNotify(this,
						"Your input could not be recorded. Please try again.");
			}
			// submit data to wherever
			break;

		}
	}

	/**
	 * Create and show the food categories dialog
	 */
	private void ShowCategoriesDialog() {
		// Get categories
		final FoodCategory[] categories = lookUpAdapter.getCategories();
		CharSequence[] categoriesStrings = new CharSequence[categories.length];
		for (int i = 0; i < categories.length; i++) {
			categoriesStrings[i] = categories[i].getName();
		}

		OnClickListener categoriesClickListener = new OnClickListener() {

			@Override
			public void onClick(final DialogInterface dialog, int item) {
				// TODO Auto-generated method stub
				final FoodImageAdapter foodAdapter = new FoodImageAdapter(
						context);

				// Get food items from database and populate the
				// adapter
				FoodItem[] foodItems = lookUpAdapter
						.getFoodsByCategory(categories[item].getId());
				foodAdapter.addItems(foodItems);

				FoodGalleryDialog foodGalleryDialog = new FoodGalleryDialog(
						context, foodAdapter, adapter);
				foodGalleryDialog.show();
				// DialogHandler.createGridViewDialog("Choose a food:",
				// foodAdapter, context, adapter).show();
			}
		};

		DialogHandler.createSingleSelectionDialog("Categories",
				categoriesStrings, context, categoriesClickListener).show();
	}

	@Override
	public boolean onContextItemSelected(MenuItem aItem) {
		AdapterContextMenuInfo menuInfo = (AdapterContextMenuInfo) aItem
				.getMenuInfo();
		/*
		 * Get the selected item out of the Adapter by its position. Reminder
		 * selectedItem = (Reminder) listView.getAdapter().getItem(
		 * menuInfo.position);
		 */

		/* Switch on the ID of the item, to get what the user selected. */
		switch (aItem.getItemId()) {
		case CONTEXTMENU_DELETEITEM:
			/* Remove it from the list. */
			FoodInputListAdapter adapter = (FoodInputListAdapter) listView
					.getAdapter();
			adapter.removeItem(menuInfo.position);

			return true; /* true means: "we handled the event". */
			/*
			 * case CONTEXTMENU_EDITITEM: startActivity(new Intent(this,
			 * AddReminderActivity.class).putExtra( "reminderId",
			 * selectedItem.getId()).putExtra("activity", ReminderType));
			 */
		}
		return false;
	}
}
