package mqp.momometer;

import java.io.IOException;
import java.util.LinkedHashMap;
import java.util.Map;

import mpq.momometer.repositories.SharedPreferencesAdapter;
import mqp.momometer.health.HealthGDataClient;
import mqp.momometer.health.HealthGDataClient.AuthenticationException;
import mqp.momometer.health.HealthGDataClient.InvalidProfileException;
import mqp.momometer.helpers.DialogHandler;
import android.accounts.Account;
import android.accounts.AccountManager;
import android.accounts.AuthenticatorException;
import android.accounts.OperationCanceledException;
import android.app.Activity;
import android.app.Dialog;
import android.content.Context;
import android.content.DialogInterface;
import android.content.DialogInterface.OnClickListener;
import android.content.Intent;
import android.net.Uri;
import android.os.Bundle;
import android.view.View;

public class GHealthSetupActivity extends Activity{

	private static final int ACTIVITY_AUTHENTICATE = 0;

	private static final String SERVICE_NAME = "health";

	private String authToken;
	private Map<String, String> profiles = new LinkedHashMap<String, String>();

	private HealthGDataClient client = new HealthGDataClient(SERVICE_NAME);

	final Context context = this; // Application context to pass to the listener

	@Override
	public void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.setupgoogleaccount);
	}

	/**
	 * Allow user to select the google account to associate with 
	 * the app
	 */
	private void GetGoogleHealthAccount()
	{	
		final AccountManager manager = AccountManager.get(this);
		final Account[] accounts = manager.getAccountsByType("com.google");
		final int size = accounts.length;
		String[] names = new String[size];

		for (int i = 0; i < size; i++)
		{
			names[i] = accounts[i].name;
		}

		OnClickListener listener = new OnClickListener() {

			@Override
			public void onClick(DialogInterface dialog, int which) {

				// Get selected account
				Account selectedAccount = accounts[which];

				// Store account name in shared preferences
				SharedPreferencesAdapter.setGHealthAccount(context, selectedAccount.name);

				// Grab the authorization token
				GetAuthorizationTokenForAccount(manager, selectedAccount);
			}
		};

		Dialog accountDialog = DialogHandler.createSingleSelectionDialog("Select a Google account", names, this, listener);
		accountDialog.show();				
	}	

	/**
	 * 
	 * @param manager
	 * @param account
	 */
	private void GetAuthorizationTokenForAccount(AccountManager manager, Account account)
	{
		// Get the authorization token
		try {
			Bundle bundle = manager.getAuthToken(account, SERVICE_NAME, true, null, null).getResult();
			if (bundle.containsKey(AccountManager.KEY_INTENT)) {
				Intent intent = bundle.getParcelable(AccountManager.KEY_INTENT);
				int flags = intent.getFlags();
				flags &= ~Intent.FLAG_ACTIVITY_NEW_TASK;
				intent.setFlags(flags);
				startActivityForResult(intent, ACTIVITY_AUTHENTICATE);
			} 
			else if (bundle.containsKey(AccountManager.KEY_AUTHTOKEN))
			{
				authToken = bundle.getString(AccountManager.KEY_AUTHTOKEN);
				client.setAuthToken(authToken);	
				GetProfile();
			}
		} catch (OperationCanceledException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		} catch (AuthenticatorException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		} catch (IOException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}		
	}

	/**
	 * 
	 */
	private void GetProfile()
	{
		try {
			profiles = client.retrieveProfiles();

			String[] profileNames = profiles.values().toArray(new String[profiles.size()]);
			OnClickListener listener = new OnClickListener() {

				@Override
				public void onClick(DialogInterface dialog, int which) {

					// Get the profile id
					String pid = profiles.keySet().toArray(new String[profiles.size()])[which];

					// Store the id in the shared preferences
					SharedPreferencesAdapter.setGHealthProfile(context, pid);

					// Set the profile id on the client
					client.setProfileId(pid);

					DialogHandler.toastNotify(context, "You have successfully set up your Google Health account!");

					// Proceed to app setup activity
					startActivity(new Intent(context, SetupActivity.class));
				}
			};

			Dialog dialog = DialogHandler.createSingleSelectionDialog("Select a Health profile", profileNames, this, listener);
			dialog.show();

		} catch (AuthenticationException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		} catch (InvalidProfileException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
	}

	private void gotAccount(boolean tokenExpired) {		    
		String accountName = SharedPreferencesAdapter.getGHealthAccountName(this);

		if (accountName != null) {
			AccountManager manager = AccountManager.get(this);
			Account[] accounts = manager.getAccountsByType("com.google");
			int size = accounts.length;
			for (int i = 0; i < size; i++) {
				Account account = accounts[i];
				if (accountName.equals(account.name)) {
					if (tokenExpired) {
						manager.invalidateAuthToken("com.google", authToken);
					}
					GetAuthorizationTokenForAccount(manager, account);
					return;
				}
			}
		}
	}

	@Override
	protected void onActivityResult(int requestCode, int resultCode, Intent data) {
		super.onActivityResult(requestCode, resultCode, data);

		switch (requestCode) {
		case ACTIVITY_AUTHENTICATE:
			if (resultCode == RESULT_OK) {
				gotAccount(false);
			} 
			break;

		}
	}
	/**
	 * 
	 * @param v
	 */
	public void btnHandler(View v)
	{
		switch (v.getId())
		{
		case R.id.btnSetup:
			GetGoogleHealthAccount();
			break;
		case R.id.btnWhatIsGoogle:
			Uri uriUrl = Uri.parse("http://www.google.com/intl/en-US/health/about/");  
			Intent launchBrowser = new Intent(Intent.ACTION_VIEW, uriUrl);  
			startActivity(launchBrowser);  
			break;
		case R.id.btnCancel:
			finish();
			break;

		}
	}

}
