package mqp.momometer;

import java.util.ArrayList;

import mpq.momometer.repositories.LookUpsDataAdapter;
import mqp.momometer.R.color;
import mqp.momometer.classes.Screens;
import mqp.momometer.classes.TabViewInformation;
import mqp.momometer.helpers.ActivityImageGenerator;
import mqp.momometer.helpers.ActivityTitleGenerator;
import mqp.momometer.helpers.HelperFunctions;
import mqp.momometer.helpers.TabFactory;
import android.app.TabActivity;
import android.content.Intent;
import android.graphics.drawable.Drawable;
import android.os.Bundle;
import android.view.View;
import android.widget.Button;
import android.widget.ImageView;
import android.widget.TabHost;
import android.widget.TextView;

public class TabFactoryActivity extends TabActivity{

	private int activity;
	private LookUpsDataAdapter lookUpsAdapter;

	public static final int OVERVIEW = 0;
	public static final int DETAILS = 1;
	public static final int  INPUT = 2;
	private static final int WEEK = 5; // We only have facts starting from week 5

	/** Called when the activity is first created. */
	@Override
	public void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.tabcontainer);

		// Get the activity type
		activity = this.getIntent().getExtras().getInt("Activity");

		int startingTab = this.getIntent().getExtras().getInt("startingTab");

		/**
		 * MODIFY HEADER INFO AS NEEDED
		 */		
		//### Get number of reminders
		TextView txtReminders = (TextView)findViewById(R.id.txtActivityMessage);

		//### Get baby fact		
		int currentWeek = HelperFunctions.getCurrentWeek(this);
		lookUpsAdapter = new LookUpsDataAdapter(this);

		if (currentWeek >= WEEK){
			String babyFact =  lookUpsAdapter.getBabyFactByWeek(currentWeek);
			txtReminders.setText("Week " + currentWeek + ": " +  babyFact);
		}

		//### Get Activity Title from ActivityTitleGenerator.java and change the title
		TextView lblHeader = (TextView)findViewById(R.id.lblHeaderTitle);
		String headerTitle = ActivityTitleGenerator.GetActivityTitleFromActivity(this, activity);
		lblHeader.setText(headerTitle);

		//### Get Drawable image for the imgActivityIcon in tabcontainer.xml
		ImageView imgViewActivity = (ImageView)findViewById(R.id.imgActivityIcon);
		Drawable imgDrawableActivity = ActivityImageGenerator.GetActivityImageFromActivity(this, activity);
		imgViewActivity.setImageDrawable(imgDrawableActivity);

		/** 
		 * TAB CREATION
		 */		

		TabHost tabHost = getTabHost(); // The activity TabHost
		TabHost.TabSpec spec; // Resusable TabSpec for each tab	

		ArrayList<TabViewInformation> tabsInfo = TabFactory.GetTabInformationFromActivity(this, activity);

		for(TabViewInformation tabInfo : tabsInfo)
		{			
			// Initialize a TabSpec for each tab and add it to the TabHost
			spec = tabHost
			.newTabSpec(tabInfo.TabName.toLowerCase())
			.setIndicator(tabInfo.TabName, getResources().getDrawable(tabInfo.icon))
			.setContent(tabInfo.intent);
			tabHost.addTab(spec);			
		}

		tabHost.setCurrentTab(startingTab);	
		
	}    

	public void btnNextFactHandler(View view)
	{
		//### Get new fact
		TextView txtReminders = (TextView)findViewById(R.id.txtActivityMessage);
		int currentWeek = HelperFunctions.getCurrentWeek(this);
		if (currentWeek >= WEEK){
			String babyFact = lookUpsAdapter.getBabyFactByWeek(HelperFunctions.getCurrentWeek(this));
			txtReminders.setText("Week " + currentWeek + ": " +babyFact);
		}
	}

	public void btnFeedbackHandler(View view)
	{
		Bundle bundle = new Bundle();
		bundle.putInt("Activity", activity);
		// Get feedback for activity
		startActivity(new Intent(this,FeedBackActivity.class).putExtras(bundle));

	}

	public void btnHelpHandler(View view)
	{
		TabHost tabHost = getTabHost();		
		int screen = activity; 
		
		// Add current tab to the screen number because each of the tracking screens have 3 tabs
		if (screen == Screens.ACTIVITYOVERVIEWSCREEN || screen == Screens.NUTRITIONOVERVIEWSCREEN || screen == Screens.WEIGHTOVERVIEWSCREEN){
			screen += tabHost.getCurrentTab();
		}
		Bundle bundle = new Bundle();
		bundle.putInt("Screen", screen);
		bundle.putInt("Activity", activity);
		// Get feedback for activity    
		startActivity(new Intent(this,HelpActivity.class).putExtras(bundle));
	}

	public void btnInfoHandler(View view)
	{
		Bundle bundle = new Bundle();
		bundle.putInt("Activity", activity);
		// Get feedback for activity
		startActivity(new Intent(this,InformationActivity.class).putExtras(bundle));
	}

	public void btnHomeHandler(View view){
		startActivity(new Intent(this, HomeActivity.class));
	}
	public void btnBabyFactSwitchHandler(View view){
		Button btnBabyFactSwitch = (Button)findViewById(R.id.btnBabyFactSwitch);
		Button btnNextBaby = (Button)findViewById(R.id.btnNextBabyFact);
		TextView babyFactVisibility = (TextView)findViewById(R.id.txtActivityMessage);
		if(babyFactVisibility.getVisibility() != View.VISIBLE){
			btnBabyFactSwitch.setText("Hide Baby Facts");
			babyFactVisibility.setVisibility(View.VISIBLE);	
			btnNextBaby.setVisibility(View.VISIBLE);
			btnBabyFactSwitch.setCompoundDrawablesWithIntrinsicBounds(R.drawable.ic_hide, 0, 0, 0);
		}else{
			btnBabyFactSwitch.setText("Show Baby Facts");
			babyFactVisibility.setVisibility(View.GONE);
			btnNextBaby.setVisibility(View.GONE);
			btnBabyFactSwitch.setCompoundDrawablesWithIntrinsicBounds(R.drawable.ic_show, 0, 0, 0);
		}

	}
}
