package mqp.momometer.alarms;

import java.util.Calendar;
import java.util.GregorianCalendar;

import mqp.momometer.classes.ActivityType;
import mqp.momometer.classes.Day;
import mqp.momometer.classes.Reminder;

import android.app.AlarmManager;
import android.app.PendingIntent;
import android.content.Context;
import android.content.Intent;

public class AlarmController {

	public static void AddNewReminder(Context context, Reminder reminder) {
		Intent intent = null; // = new Intent(context, RepeatingAlarm.class);

		switch (reminder.getType()) {
		case ActivityType.WEIGHTTRACKING:
			intent = new Intent(context, WeightInputAlarm.class);
			break;
		case ActivityType.ACTIVITYTRACKING:
			intent = new Intent(context, ActivityInputAlarm.class);
			break;
		case ActivityType.FOODTRACKING:
			intent = new Intent(context, FoodInputAlarm.class);
			break;
		}		
		
		// Loop through each day to create a repeating alarm
		for (Day d : reminder.getDays()) {
			Calendar cur_cal = new GregorianCalendar();
			cur_cal.setTimeInMillis(System.currentTimeMillis());// set the current time and date for this calendar
			
			Calendar cal = new GregorianCalendar();
			//cal.add(Calendar.DAY_OF_YEAR, cur_cal.get(Calendar.DAY_OF_YEAR));
			cal.set(Calendar.HOUR_OF_DAY, reminder.getTime().getHours());
			cal.set(Calendar.MINUTE, reminder.getTime().getMinutes());
			cal.set(Calendar.SECOND, 0);
			cal.set(Calendar.MILLISECOND, 0);
			cal.set(Calendar.MONTH, cur_cal.get(Calendar.MONTH));
			cal.set(Calendar.YEAR, cur_cal.get(Calendar.YEAR));
			
			// Set the day of the week
			cal.set(Calendar.DAY_OF_WEEK, d.getDay() + 1);
			
			// Check if the day is past
			int cur_day = cur_cal.get(Calendar.DAY_OF_WEEK);
			
			if (cur_day > d.getDay()+1)
			{
				cal.add(Calendar.DAY_OF_YEAR, 7);
			}
			
			// Construct unique id for each day
			String id = String.valueOf(reminder.getId()) + String.valueOf(d.Day);
			
			// Create a different pending intent for each day
			PendingIntent sender = PendingIntent
					.getBroadcast(context, Integer.parseInt(id), intent, 0);
			
			// Schedule the alarm! Will repeat every week
			AlarmManager am = (AlarmManager) context
					.getSystemService(Context.ALARM_SERVICE);
			am.setRepeating(AlarmManager.RTC_WAKEUP, cal.getTimeInMillis(), AlarmManager.INTERVAL_DAY*7, sender);
		}
	}
	
	public static void DeleteReminder(Context context, Reminder reminder)
	{
		Intent intent = null; // = new Intent(context, RepeatingAlarm.class);

		switch (reminder.getType()) {
		case ActivityType.WEIGHTTRACKING:
			intent = new Intent(context, WeightInputAlarm.class);
			break;
		case ActivityType.ACTIVITYTRACKING:
			intent = new Intent(context, ActivityInputAlarm.class);
			break;
		case ActivityType.FOODTRACKING:
			intent = new Intent(context, FoodInputAlarm.class);
			break;
		}

		for (Day d : reminder.getDays()) {

			// Construct unique id for the alarm
			String id = String.valueOf(reminder.getId()) + String.valueOf(d.Day);
			
			// Create a different pending intent for each day
			PendingIntent sender = PendingIntent
					.getBroadcast(context, Integer.parseInt(id), intent, 0);
			
			// Schedule the alarm!
			AlarmManager am = (AlarmManager) context
					.getSystemService(Context.ALARM_SERVICE);
			am.cancel(sender);
		}		
	}

	public static void SetupAppAlarms(Context context)
	{
		AlarmManager am = (AlarmManager)context.getSystemService(Context.ALARM_SERVICE);
		
		Calendar cur_cal = new GregorianCalendar();
		cur_cal.setTimeInMillis(System.currentTimeMillis());// set the current time and date for this calendar
		
		Calendar cal = new GregorianCalendar();
		cal.set(Calendar.HOUR_OF_DAY, 0);
		cal.set(Calendar.MINUTE, 00);
		cal.set(Calendar.MONTH, cur_cal.get(Calendar.MONTH));
		cal.set(Calendar.YEAR, cur_cal.get(Calendar.YEAR));
		
		// Alarm for day and week tracker
		cal.set(Calendar.DAY_OF_YEAR, cur_cal.get(Calendar.DAY_OF_YEAR) + 1);
		
	}
}
