package mqp.momometer.feedback;

import android.content.Context;
import mqp.momometer.classes.GwgTrajectoryData;
import mqp.momometer.helpers.FactGenerator;
import mqp.momometer.helpers.HelperFunctions;

public class WeightFeedBackGenerator {

	private static final double UNDERWEIGHT = 18.5;
	private static final double NORMALWEIGHT = 24.9;
	private static final double OVERWEIGHT = 29.9;
	private static final double OBESE = 30.0;	

	/**
	 * 
	 * @param context
	 * @param currentWeek
	 * @return
	 */
	public static GwgTrajectoryData GetGWGTrajectory(Context context, int currentWeek)
	{		
		// Get pre-pregnancy BMI
		double prepregnancyBMI = HelperFunctions.getPrepregnancyBMI(context);

		if (prepregnancyBMI < UNDERWEIGHT)
		{
			return new GwgTrajectoryData(40, 28, 4.4, 1.1, 1.3,1,1.3,1);
		}
		else if (prepregnancyBMI <= NORMALWEIGHT)
		{
			return new GwgTrajectoryData(35, 25, 4.4, 1.1, 1, 0.8, 1, 0.8);
		}
		else if (prepregnancyBMI <= OVERWEIGHT)
		{
			return new GwgTrajectoryData(25, 15, 4.4, 1.1, 0.7, 0.5, 0.7, 0.5);
		}
		else if (prepregnancyBMI >= OBESE)
		{
			return new GwgTrajectoryData(20, 11, 4.4, 1.1, 0.6, 0.4, 0.6, 0.4);
		}

		return null;
	}

	/**
	 * 
	 * @param context
	 * @param currentWeek
	 * @param gwg
	 * @return
	 */
	public static int GetQuantitativeFeedbackByWeek(Context context, int currentWeek, double gwg)
	{
		// Get GWG trajectory
		GwgTrajectoryData gwgTrajectory = WeightFeedBackGenerator.GetGWGTrajectory(context, currentWeek);

		double lowerLimit = 0.0;
		double upperLimit = 0.0;

		// Retrieve the upper and lower limits to compare the gwg to
		if (currentWeek <= 12) // First trimester
		{
			lowerLimit = gwgTrajectory.getGwgTrajectoryLowerFirstTri();
			upperLimit = gwgTrajectory.getGwgTrajectoryUpperFirstTri();
		}
		else if (currentWeek <= 24) // Second trimester
		{
			lowerLimit = gwgTrajectory.getGwgTrajectoryLowerSecondTri();
			upperLimit = gwgTrajectory.getGwgTrajectoryUpperSecondTri();			
		}
		else 
		{
			lowerLimit = gwgTrajectory.getGwgTrajectoryLowerThirdTri();
			upperLimit = gwgTrajectory.getGwgTrajectoryUpperThirdTri();
		}

		if (lowerLimit > 0.0 && upperLimit > 0.0)
		{
			if (gwg >= lowerLimit && gwg <= upperLimit)
			{
				double quoefficient = upperLimit - lowerLimit;
				double ratio = gwg / quoefficient;
				int dp = (int)ratio * 180 + 100;
				return dp;
			}
			else if (gwg < lowerLimit)
			{
				return 90;
			}
			else if (gwg > upperLimit)
			{
				return 100;
			}		
		}
		return 0;
	}

	/**
	 * Get qualitative feedback on the GWG for the current week
	 * @param context
	 * @param currentWeek
	 * @param gwg
	 * @return
	 */
	public static String GetQualitativeFeedback(Context context, int currentWeek, double gwg)
	{
		// Get GWG trajectory
		GwgTrajectoryData gwgTrajectory = WeightFeedBackGenerator.GetGWGTrajectory(context, currentWeek);

		double lowerLimit = 0.0;
		double upperLimit = 0.0;

		// Retrieve the upper and lower limits to compare the gwg to
		if (currentWeek <= 12) // First trimester
		{
			lowerLimit = gwgTrajectory.getGwgTrajectoryLowerFirstTri();
			upperLimit = gwgTrajectory.getGwgTrajectoryUpperFirstTri();
		}
		else if (currentWeek <= 24) // Second trimester
		{
			lowerLimit = gwgTrajectory.getGwgTrajectoryLowerSecondTri();
			upperLimit = gwgTrajectory.getGwgTrajectoryUpperSecondTri();			
		}
		else 
		{
			lowerLimit = gwgTrajectory.getGwgTrajectoryLowerThirdTri();
			upperLimit = gwgTrajectory.getGwgTrajectoryUpperThirdTri();
		}

		if (lowerLimit > 0.0 && upperLimit > 0.0)
		{
			if (gwg >= lowerLimit && gwg <= upperLimit)
			{
				return "You are doing a great job in gaining the right amount of weight. Keep it up!";
			}
			else if (gwg < lowerLimit)
			{
				String feedback = "You are not gaining enough weight this week. This week you are supposed to gain at least " 
					+ lowerLimit + "lbs."; 
				if (gwg < 0 ) {
					feedback += " However, you have lost " + HelperFunctions.formatDouble(gwg) + " lbs.";
				}
				else {
					feedback += " However, you have only gained " + HelperFunctions.formatDouble(gwg) + " lbs.";
				}
				return feedback;
			}
			else if (gwg > upperLimit)
			{
				return "Your weight gain is a little off this week. Maybe you can try exercising more. Here is a friendly tip: "
				+ FactGenerator.getActivityFact(context);
			}		
		}
		return null;
	}

}
