package mqp.momometer.helpers;

import java.util.Random;

import android.content.Context;
import android.database.sqlite.SQLiteDatabase;
import android.database.sqlite.SQLiteException;
import mqp.momometer.R;
import mqp.momometer.classes.FoodCategory;
import mqp.momometer.classes.FoodGroup;

public class DbSqlScript {

	private static final String DB_NAME = "momometerDb";
	private static SQLiteDatabase database;

	public static final String WEIGHT_REMINDERS = "weightReminders";
	public static final String WEIGHT_INPUT = "weightInput";
	public static final String GWG_TRAJECTORY = "gwgTrajectory";

	public static final String ACTIVITY_INPUT = "activityInput";
	public static final String ACTIVITY_TYPE = "activityType";
	public static final String ACTIVITY_NAME = "activityName";

	public static final String MEAL_TYPE = "mealType";
	public static final String FOOD_INPUT = "foodInput";
	public static final String FOOD_LIST = "foodList";
	public static final String FOOD_CATEGORIES = "foodCategories";
	public static final String FOOD_GROUPS = "foodGroups";

	public static final String TIME_DURATION = "timeDuration";

	public static final String BABY_FACTS = "babyFacts";
	public static final String APP_INFORMATION = "appInformation";


	public static void CreateDatabaseAndTables(Context context) {
		try {
			// Create database
			database = context.openOrCreateDatabase(DB_NAME,
					Context.MODE_PRIVATE, null);

			// Create reminders table
			database.execSQL("CREATE TABLE IF NOT EXISTS "
					+ WEIGHT_REMINDERS
					+ "(id INTEGER PRIMARY KEY, type INTEGER, hour INTEGER, minute INTEGER, "
					+ "monday INTEGER, tuesday INTEGER, wednesday INTEGER, thursday INTEGER, "
					+ "friday INTEGER, saturday INTEGER, sunday INTEGER)");

			// Create weight input table
			database.execSQL("CREATE TABLE IF NOT EXISTS " + WEIGHT_INPUT
					+ "(id INTEGER PRIMARY KEY, weight NUMERIC, type INTEGER, timestamp TEXT, dayofweek INTEGER, week INTEGER, dayofmonth INTEGER, month INTEGER, year INTEGER)");

			// Create activity input table
			database.execSQL("CREATE TABLE IF NOT EXISTS "
					+ ACTIVITY_INPUT
					+ "(id INTEGER PRIMARY KEY, type INTEGER, activity INTEGER, duration INTEGER, timestamp TEXT,dayofweek INTEGER, week INTEGER, dayofmonth INTEGER, month INTEGER, year INTEGER)");

			// Create the activity type table
			database.execSQL("CREATE TABLE IF NOT EXISTS " + ACTIVITY_TYPE
					+ "(id INTEGER PRIMARY KEY, description TEXT)");

			// Create the activity name table
			database.execSQL("CREATE TABLE IF NOT EXISTS "
					+ ACTIVITY_NAME
					+ "(id INTEGER PRIMARY KEY, type INTEGER, description TEXT, FOREIGN KEY(type) REFERENCES "
					+ ACTIVITY_TYPE + "(id))");

			// Create the food groups tables
			database.execSQL("CREATE TABLE IF NOT EXISTS " + FOOD_GROUPS + 
			"(id INTEGER PRIMARY KEY, foodGroup TEXT)");

			// Create the food categories table
			database.execSQL("CREATE TABLE IF NOT EXISTS " + FOOD_CATEGORIES
					+ "(id INTEGER PRIMARY KEY, foodGroup INTEGER, category TEXT)");

			// Create the food list table
			database.execSQL("CREATE TABLE IF NOT EXISTS "
					+ FOOD_LIST
					+ "(id INTEGER PRIMARY KEY, name TEXT, description TEXT, category INTEGER, calories INTEGER, image INTEGER,"
					+ "FOREIGN KEY(category) REFERENCES " + FOOD_CATEGORIES
					+ "(id))");

			// Create the meal type table
			database.execSQL("CREATE TABLE IF NOT EXISTS " 
					+ MEAL_TYPE 
					+ "(id INTEGER PRIMARY KEY, description TEXT)");

			// Create the the food input table
			database.execSQL("CREATE TABLE IF NOT EXISTS "
					+ FOOD_INPUT
					+ "(id INTEGER PRIMARY KEY, foodId INTEGER, servings INTEGER, mealType INTEGER, timestamp TEXT, dayofweek INTEGER, week INTEGER, dayofmonth INTEGER, month INTEGER, year INTEGER,"
					+ "FOREIGN KEY (foodId) REFERENCES " + FOOD_LIST + "(id))");

			// Create the time duration table
			database.execSQL("CREATE TABLE IF NOT EXISTS " + TIME_DURATION
					+ "(id INTEGER PRIMARY KEY, duration NUMERIC)");

			// Create the app information table
			database.execSQL("CREATE TABLE IF NOT EXISTS " + APP_INFORMATION
					+ "(id INTEGER PRIMARY KEY, screenId INTEGER, description TEXT)");

			// Create the baby facts table
			database.execSQL("CREATE TABLE IF NOT EXISTS " + BABY_FACTS
					+ "(id INTEGER PRIMARY KEY, week INTEGER, number INTEGER, description TEXT)");			

		} catch (SQLiteException se) {
			throw se;
		}
	}

	public static void PopulateDatabase(Context context) {

		// Populate the activity type table
		database.execSQL("insert into " + ACTIVITY_TYPE
				+ "(description) values('Standing')");
		database.execSQL("insert into " + ACTIVITY_TYPE
				+ "(description) values('Sitting')");
		database.execSQL("insert into " + ACTIVITY_TYPE
				+ "(description) values('Exercising')");

		// Populate the activity name table
		database.execSQL("insert into " + ACTIVITY_NAME
				+ "(type, description) values(1, 'Walking')");
		database.execSQL("insert into " + ACTIVITY_NAME
				+ "(type, description) values(1, 'Standing')");
		database.execSQL("insert into " + ACTIVITY_NAME
				+ "(type, description) values(1, 'Doing chores')");
		database.execSQL("insert into " + ACTIVITY_NAME
				+ "(type, description) values(2, 'Sitting')");
		database.execSQL("insert into " + ACTIVITY_NAME
				+ "(type, description) values(2, 'Laying Down')");
		database.execSQL("insert into " + ACTIVITY_NAME
				+ "(type, description) values(2, 'Napping')");
		database.execSQL("insert into " + ACTIVITY_NAME
				+ "(type, description) values(3, 'Running')");
		database.execSQL("insert into " + ACTIVITY_NAME
				+ "(type, description) values(3, 'Swimming')");
		database.execSQL("insert into " + ACTIVITY_NAME
				+ "(type, description) values(3, 'Boxing')");

		// Populate the time duration table
		database.execSQL("insert into " + TIME_DURATION
				+ "(duration) values(15)");
		database.execSQL("insert into " + TIME_DURATION
				+ "(duration) values(20)");
		database.execSQL("insert into " + TIME_DURATION
				+ "(duration) values(30)");
		database.execSQL("insert into " + TIME_DURATION
				+ "(duration) values(45)");
		database.execSQL("insert into " + TIME_DURATION
				+ "(duration) values(60)");		

		// Populate the meal type table
		database.execSQL("insert into " + MEAL_TYPE 
				+ "(description) values('Breakfast')");
		database.execSQL("insert into " + MEAL_TYPE 
				+ "(description) values('Lunch')");
		database.execSQL("insert into " + MEAL_TYPE 
				+ "(description) values('Dinner')");
		database.execSQL("insert into " + MEAL_TYPE 
				+ "(description) values('Snack')");



		// Populate the baby facts table
		database.execSQL("insert into " + BABY_FACTS
				+ "(week, number, description) values(5, 1, 'Your baby currently looks like a curled tube and is about the size of a pumpkin seed.')");
		database.execSQL("insert into " + BABY_FACTS
				+ "(week, number,  description) values(5, 2, 'Your baby has developed arm and leg buds.')");
		database.execSQL("insert into " + BABY_FACTS
				+ "(week, number,  description) values(5, 3, 'The tube that will become your baby''s digestive tract has taken shape.')");
		database.execSQL("insert into " + BABY_FACTS
				+ "(week, number,  description) values(6, 1, 'Your baby''s heart is beating approximately 80 times per minute.')");
		database.execSQL("insert into " + BABY_FACTS
				+ "(week, number,  description) values(6, 2, 'Your baby''s nose, mouth and ears are beginning to form.')");
		database.execSQL("insert into " + BABY_FACTS
				+ "(week, number,  description) values(6, 3, 'Webbed toes and fingers are poking out from your baby''s hands and feet.')");
		database.execSQL("insert into " + BABY_FACTS
				+ "(week, number,  description) values(6, 4, 'The inner ear begins to develop.')");
		database.execSQL("insert into " + BABY_FACTS
				+ "(week, number,  description) values(7, 1, 'Bones are forming in your baby, but they will not harden for a few weeks.')");
		database.execSQL("insert into " + BABY_FACTS
				+ "(week, number,  description) values(7, 2, 'Your baby''s Fingers and toes are now present.')");
		database.execSQL("insert into " + BABY_FACTS
				+ "(week, number,  description) values(7, 3, 'Your baby''s external genitals are starting to develop.')");
		database.execSQL("insert into " + BABY_FACTS
				+ "(week, number,  description) values(7, 4, 'Eyelids form but remain closed.')");
		database.execSQL("insert into " + BABY_FACTS
				+ "(week, number,  description) values(8, 1, 'Your baby is now 1 inch long.')");
		database.execSQL("insert into " + BABY_FACTS
				+ "(week, number,  description) values(8, 2, 'By the end of this month, all major organs and body systems have begun developing.')");
		database.execSQL("insert into " + BABY_FACTS
				+ "(week, number,  description) values(8, 3, 'Breathing tubes extend from the throat to the developing lungs.')");
		database.execSQL("insert into " + BABY_FACTS
				+ "(week, number,  description) values(8, 4, 'Nerve cells in the brain are begging to connect to each other.')");
		database.execSQL("insert into " + BABY_FACTS
				+ "(week, number,  description) values(8, 5, 'This week is the end of the embryonic phase of development. After this week, number,  the baby is called a fetus.')");
		database.execSQL("insert into " + BABY_FACTS
				+ "(week, number,  description) values(9, 1, 'Your baby has grown to about 2 inches in length.')");
		database.execSQL("insert into " + BABY_FACTS
				+ "(week, number,  description) values(9, 2, 'Your baby''s buds for future teeth are appearing.')");
		database.execSQL("insert into " + BABY_FACTS
				+ "(week, number,  description) values(9, 3, 'Your baby''s intestines are beginning to form.')");

		database.close();
	}

	public static void ClearTables(Context context) {
		try {
			// Create database
			database = context.openOrCreateDatabase(DB_NAME,
					Context.MODE_PRIVATE, null);
			database.execSQL("DROP TABLE IF EXISTS " + FOOD_INPUT);
			database.execSQL("DROP TABLE IF EXISTS " + WEIGHT_INPUT);
			database.execSQL("DROP TABLE IF EXISTS " + ACTIVITY_INPUT);
			/*database.execSQL("DROP TABLE IF EXISTS " + BABY_FACTS);*/
			database.close();
		} catch (SQLiteException se) {
			// Do something
		}
	}	

	public static void InsertTestInputData(Context context)
	{
		Random generator = new Random();

		try{
			database = context.openOrCreateDatabase(DB_NAME,
					Context.MODE_PRIVATE, null);

			// Insert test weight input data		
			database.execSQL("insert into " + WEIGHT_INPUT + "(weight, week) values(170, 1)");
			database.execSQL("insert into " + WEIGHT_INPUT + "(weight, week) values(170.4, 1)");
			database.execSQL("insert into " + WEIGHT_INPUT + "(weight, week) values(170.7, 1)");
			database.execSQL("insert into " + WEIGHT_INPUT + "(weight, week) values(171.2, 2)");
			database.execSQL("insert into " + WEIGHT_INPUT + "(weight, week) values(171.55, 2)");
			database.execSQL("insert into " + WEIGHT_INPUT + "(weight, week) values(171.94, 2)");
			database.execSQL("insert into " + WEIGHT_INPUT + "(weight, week) values(172.33, 3)");
			database.execSQL("insert into " + WEIGHT_INPUT + "(weight, week) values(172.72, 3)");
			database.execSQL("insert into " + WEIGHT_INPUT + "(weight, week) values(173.11, 4)");
			database.execSQL("insert into " + WEIGHT_INPUT + "(weight, week) values(173.5, 4)");
			database.execSQL("insert into " + WEIGHT_INPUT + "(weight, week) values(173.89, 5)");
			database.execSQL("insert into " + WEIGHT_INPUT + "(weight, week) values(174.28, 6)");
			database.execSQL("insert into " + WEIGHT_INPUT + "(weight, week) values(174.67, 6)");
			database.execSQL("insert into " + WEIGHT_INPUT + "(weight, week) values(175.06, 7)");
			database.execSQL("insert into " + WEIGHT_INPUT + "(weight, week) values(175.45, 7)");
			database.execSQL("insert into " + WEIGHT_INPUT + "(weight, week) values(175.84, 7)");
			database.execSQL("insert into " + WEIGHT_INPUT + "(weight, week) values(176.23, 8)");
			database.execSQL("insert into " + WEIGHT_INPUT + "(weight, week) values(176.62, 8)");
			database.execSQL("insert into " + WEIGHT_INPUT + "(weight, week) values(177.01, 9)");
			database.execSQL("insert into " + WEIGHT_INPUT + "(weight, week) values(177.4, 9)");
			database.execSQL("insert into " + WEIGHT_INPUT + "(weight, week) values(177.79, 10)");
			database.execSQL("insert into " + WEIGHT_INPUT + "(weight, week) values(178.18, 10)");
			database.execSQL("insert into " + WEIGHT_INPUT + "(weight, week) values(178.57, 10)");
			database.execSQL("insert into " + WEIGHT_INPUT + "(weight, week) values(178.96, 11)");
			database.execSQL("insert into " + WEIGHT_INPUT + "(weight, week) values(179.35, 11)");
			database.execSQL("insert into " + WEIGHT_INPUT + "(weight, week) values(179.74, 12)");
			database.execSQL("insert into " + WEIGHT_INPUT + "(weight, week) values(180.13, 12)");
			database.execSQL("insert into " + WEIGHT_INPUT + "(weight, week) values(180.52, 13)");
			database.execSQL("insert into " + WEIGHT_INPUT + "(weight, week) values(180.91, 13)");
			database.execSQL("insert into " + WEIGHT_INPUT + "(weight, week) values(181.3, 14)");
			database.execSQL("insert into " + WEIGHT_INPUT + "(weight, week) values(181.69, 15)");
			database.execSQL("insert into " + WEIGHT_INPUT + "(weight, week) values(182.08, 15)");
			database.execSQL("insert into " + WEIGHT_INPUT + "(weight, week) values(182.47, 16)");
			database.execSQL("insert into " + WEIGHT_INPUT + "(weight, week) values(182.86, 17)");
			database.execSQL("insert into " + WEIGHT_INPUT + "(weight, week) values(183.25, 18)");
			database.execSQL("insert into " + WEIGHT_INPUT + "(weight, week) values(183.64, 19)");
			database.execSQL("insert into " + WEIGHT_INPUT + "(weight, week) values(184.03, 20)");
			database.execSQL("insert into " + WEIGHT_INPUT + "(weight, week) values(184.42, 21)");
			database.execSQL("insert into " + WEIGHT_INPUT + "(weight, week) values(184.81, 22)");
			database.execSQL("insert into " + WEIGHT_INPUT + "(weight, week) values(185.2, 23)");
			database.execSQL("insert into " + WEIGHT_INPUT + "(weight, week) values(185.59, 24)");
			database.execSQL("insert into " + WEIGHT_INPUT + "(weight, week) values(185.98, 25)");
			database.execSQL("insert into " + WEIGHT_INPUT + "(weight, week) values(186.37, 26)");
			database.execSQL("insert into " + WEIGHT_INPUT + "(weight, week) values(186.76, 27)");
			database.execSQL("insert into " + WEIGHT_INPUT + "(weight, week) values(187.15, 28)");
			database.execSQL("insert into " + WEIGHT_INPUT + "(weight, week) values(187.54, 29)");
			database.execSQL("insert into " + WEIGHT_INPUT + "(weight, week) values(187.93, 30)");
			database.execSQL("insert into " + WEIGHT_INPUT + "(weight, week) values(188.32, 31)");
			database.execSQL("insert into " + WEIGHT_INPUT + "(weight, week) values(188.71, 32)");
			database.execSQL("insert into " + WEIGHT_INPUT + "(weight, week) values(189.1, 33)");
			database.execSQL("insert into " + WEIGHT_INPUT + "(weight, week) values(189.49, 34)");
			database.execSQL("insert into " + WEIGHT_INPUT + "(weight, week) values(189.88, 35)");
			database.execSQL("insert into " + WEIGHT_INPUT + "(weight, week) values(190.27, 36)");


			// Insert test activity input data
			for (int i = 0; i < 100; i++)
			{
				int type = generator.nextInt(3) + 1;
				int activity = type * 3 + generator.nextInt(3);
				int duration = generator.nextInt(5) + 1;
				int week = generator.nextInt(36) + 1;
				database.execSQL("insert into " + ACTIVITY_INPUT
						+ "(type, activity, duration, week) values(" + type + ", " + activity + ", " + duration + ", " + week + ")");
			}

			// Insert test food input data
			for (int i = 0; i < 250; i++)
			{
				int foodId = generator.nextInt(9) + 1;
				int servings = generator.nextInt(4) + 1;			
				int mealType = generator.nextInt(4) + 1;
				int dayofweek = generator.nextInt(7) + 1;
				int week = generator.nextInt(36) + 1;
				database.execSQL("insert into " + FOOD_INPUT
						+ "(foodId, servings, mealType, dayofweek, week) values(" + foodId + ", " + servings + ", " + mealType + ", " + dayofweek + ", " + week + ")");
			}

			database.close();		
		}catch (SQLiteException se) {
			// Do something
			throw se;
		}
	}

	public static void InsertFoodItems(Context context){

		try {
			// Open database
			database = context.openOrCreateDatabase(DB_NAME,
					Context.MODE_PRIVATE, null);

			// Populate the food list table
			database.execSQL("insert into "
					+ FOOD_LIST
					+ "(name, description, category, calories, image) values('Almonds', 'Almonds', " + FoodCategory.BEANS_AND_LEGUMES + ", 170, " +R.drawable.food000+")");
			database.execSQL("insert into "
					+ FOOD_LIST
					+ "(name, description, category, calories, image) values('Bean Sprouts', 'Bean Sprouts', " + FoodCategory.BEANS_AND_LEGUMES + ", 30, " +R.drawable.food010+")");
			database.execSQL("insert into "
					+ FOOD_LIST
					+ "(name, description, category, calories, image) values('Cannellini Beans', 'Cannellini Beans', " + FoodCategory.BEANS_AND_LEGUMES + ", 80, " +R.drawable.food027+")");
			database.execSQL("insert into "
					+ FOOD_LIST
					+ "(name, description, category, calories, image) values('Apple Juice', 'Juices', " + FoodCategory.BEVERAGES + ", 120, " +R.drawable.food002+")");
			database.execSQL("insert into "
					+ FOOD_LIST
					+ "(name, description, category, calories, image) values('Coca-Cola', 'Sodas', " + FoodCategory.BEVERAGES + ", 100, " +R.drawable.food046+")");
			database.execSQL("insert into "
					+ FOOD_LIST
					+ "(name, description, category, calories, image) values('Coffee Mate - fat free', 'Creams', " + FoodCategory.BEVERAGES + ", 20, " +R.drawable.food049+")");
			database.execSQL("insert into "
					+ FOOD_LIST
					+ "(name, description, category, calories, image) values('Cranberry Juice', 'Beverage', " + FoodCategory.BEVERAGES + ", 130, " +R.drawable.food052+")");
			database.execSQL("insert into "
					+ FOOD_LIST
					+ "(name, description, category, calories, image) values('Diet Coke', 'Sodas', " + FoodCategory.BEVERAGES + ", 0, " +R.drawable.food058+")");
			database.execSQL("insert into "
					+ FOOD_LIST
					+ "(name, description, category, calories, image) values('Bagels - Cinnamon raisin', 'Bagels', " + FoodCategory.BREADS + ", 290, " +R.drawable.food007+")");
			database.execSQL("insert into "
					+ FOOD_LIST
					+ "(name, description, category, calories, image) values('Deli Flats', 'Buns', " + FoodCategory.BREADS + ", 100, " +R.drawable.food057+")");
			database.execSQL("insert into "
					+ FOOD_LIST
					+ "(name, description, category, calories, image) values('Hamburger bun - whole wheat', 'Bus', " + FoodCategory.BREADS + ", 120, " +R.drawable.food021+")");
			database.execSQL("insert into "
					+ FOOD_LIST
					+ "(name, description, category, calories, image) values('Cheerios', 'Cheerios', " + FoodCategory.CEREAL_GRANOLA_AND_ENERGY_BARS + ", 100, " +R.drawable.food033+")");
			database.execSQL("insert into "
					+ FOOD_LIST
					+ "(name, description, category, calories, image) values('Cocoa Krispies', 'Cocoa Krispies', " + FoodCategory.CEREAL_GRANOLA_AND_ENERGY_BARS + ", 160, " +R.drawable.food047+")");
			database.execSQL("insert into "
					+ FOOD_LIST
					+ "(name, description, category, calories, image) values('Special K Original', 'Special K Original', " + FoodCategory.CEREAL_GRANOLA_AND_ENERGY_BARS + ", 110, " +R.drawable.food125+")");
			database.execSQL("insert into "
					+ FOOD_LIST
					+ "(name, description, category, calories, image) values('Teddy Grahams - all flavors', '24 crackers', " + FoodCategory.CRACKERS + ", 130, "+R.drawable.food130+")");
			database.execSQL("insert into "
					+ FOOD_LIST
					+ "(name, description, category, calories, image) values('American Cheese', 'American Cheese', " + FoodCategory.DAIRY_PRODUCTS + ", 70, " +R.drawable.food001+")");
			database.execSQL("insert into "
					+ FOOD_LIST
					+ "(name, description, category, calories, image) values('Cheddar Cheese', 'Cheddar Cheese', " + FoodCategory.DAIRY_PRODUCTS + ", 110, "+R.drawable.food032+")");
			database.execSQL("insert into "
					+ FOOD_LIST
					+ "(name, description, category, calories, image) values('Cheddar Cheese - Canned', 'Canned', " + FoodCategory.DAIRY_PRODUCTS + ", 100, "+R.drawable.food031+")");
			database.execSQL("insert into "
					+ FOOD_LIST
					+ "(name, description, category, calories, image) values('Creamy Caesar', 'Creamy Caesar', " + FoodCategory.DIPS_SALSA_AND_SPREADS + ", 170, " +R.drawable.food054+")");
			database.execSQL("insert into "
					+ FOOD_LIST
					+ "(name, description, category, calories, image) values('Salsa - All Brands', 'Salsa - All Brands', " + FoodCategory.DIPS_SALSA_AND_SPREADS + ", 10, " +R.drawable.food043+")");
			database.execSQL("insert into "
					+ FOOD_LIST
					+ "(name, description, category, calories, image) values('Canola Oil', 'Oils', " + FoodCategory.FATS_OIL_CONDIMENTS + ", 130, " +R.drawable.food028+")");
			database.execSQL("insert into "
					+ FOOD_LIST
					+ "(name, description, category, calories, image) values('Croutons - Caesar', 'Condiments', " + FoodCategory.FATS_OIL_CONDIMENTS + ", 35, " +R.drawable.food024+")");
			database.execSQL("insert into "
					+ FOOD_LIST
					+ "(name, description, category, calories, image) values('Peppercom Ranch', 'Salad Dressing', " + FoodCategory.FATS_OIL_CONDIMENTS + ", 35, " +R.drawable.food103+")");
			database.execSQL("insert into "
					+ FOOD_LIST
					+ "(name, description, category, calories, image) values('Tyson chicken boneless buffalo strips', 'Chicken', " + FoodCategory.FROZEN_FOODS + ", 230, " +R.drawable.food019+")");
			database.execSQL("insert into "
					+ FOOD_LIST
					+ "(name, description, category, calories, image) values('Apple', '1 medium', " + FoodCategory.FRUITS + ", 65, "+ R.drawable.food003+")");
			database.execSQL("insert into "
					+ FOOD_LIST
					+ "(name, description, category, calories, image) values('Banana', '1 medium', " + FoodCategory.FRUITS + ", 105, "+ R.drawable.food009+")");
			database.execSQL("insert into "
					+ FOOD_LIST
					+ "(name, description, category, calories, image) values('Blueberry', 'Blueberry', " + FoodCategory.FRUITS + ", 84, "+ R.drawable.food015+")");
			database.execSQL("insert into "
					+ FOOD_LIST
					+ "(name, description, category, calories, image) values('Coconut', 'Coconut', " + FoodCategory.FRUITS + ", 283, "+ R.drawable.food048+")");
			database.execSQL("insert into "
					+ FOOD_LIST
					+ "(name, description, category, calories, image) values('Kiwi', '1 whole', " + FoodCategory.FRUITS + ", 108, "+ R.drawable.food080+")");
			database.execSQL("insert into "
					+ FOOD_LIST
					+ "(name, description, category, calories, image) values('Melon', 'honeydew - cantaloupe', " + FoodCategory.FRUITS + ", 60, "+ R.drawable.food086+")");
			database.execSQL("insert into "
					+ FOOD_LIST
					+ "(name, description, category, calories, image) values('Oranges', 'Oranges', " + FoodCategory.FRUITS + ", 85, "+R.drawable.food098+")");
			database.execSQL("insert into "
					+ FOOD_LIST
					+ "(name, description, category, calories, image) values('Pears', '1 medium', " + FoodCategory.FRUITS + ", 59, "+R.drawable.food102+")");
			database.execSQL("insert into "
					+ FOOD_LIST
					+ "(name, description, category, calories, image) values('Beef - bottom round roast', 'Serving size 4ozs', " + FoodCategory.MEATS + ", 217, "+R.drawable.food013+")");
			database.execSQL("insert into "
					+ FOOD_LIST
					+ "(name, description, category, calories, image) values('Ground lamb', 'Serving size 4ozs', " + FoodCategory.MEATS + ", 319, "+R.drawable.food074+")");
			database.execSQL("insert into "
					+ FOOD_LIST
					+ "(name, description, category, calories, image) values('Ground pork', 'Serving size 4ozs', " + FoodCategory.MEATS + ", 298, "+R.drawable.food075+")");
			database.execSQL("insert into "
					+ FOOD_LIST
					+ "(name, description, category, calories, image) values('Almonds', 'Almond', " + FoodCategory.NUTS_AND_SEEDS + ", 170, "+R.drawable.food000+")");
			database.execSQL("insert into "
					+ FOOD_LIST
					+ "(name, description, category, calories, image) values('Cashews', 'Cashews', " + FoodCategory.NUTS_AND_SEEDS + ", 197, "+R.drawable.food030+")");
			database.execSQL("insert into "
					+ FOOD_LIST
					+ "(name, description, category, calories, image) values('Chickpeas', 'Chickpeas', " + FoodCategory.NUTS_AND_SEEDS + ", 100, "+R.drawable.food037+")");
			database.execSQL("insert into "
					+ FOOD_LIST
					+ "(name, description, category, calories, image) values('Couscous - Roasted garlic & olive oil', 'Near East - Rice', " + FoodCategory.POTATOES_RICE_PASTA_AND_GRAINS + ", 200, "+R.drawable.food051+")");
			database.execSQL("insert into "
					+ FOOD_LIST
					+ "(name, description, category, calories, image) values('Hamburger Helper - beef pasta', 'Pasta side dish - 1/2 cup', " + FoodCategory.POTATOES_RICE_PASTA_AND_GRAINS + ", 110, "+R.drawable.food012+")");
			database.execSQL("insert into "
					+ FOOD_LIST
					+ "(name, description, category, calories, image) values('Mexican style chicken flavored rice', 'Goya - Rice - 1/2 cup', " + FoodCategory.POTATOES_RICE_PASTA_AND_GRAINS + ", 320, "+R.drawable.food039+")");
			database.execSQL("insert into "
					+ FOOD_LIST
					+ "(name, description, category, calories, image) values('Rice Pilaf - Original', 'Rice', " + FoodCategory.POTATOES_RICE_PASTA_AND_GRAINS + ", 190, "+R.drawable.food120+")");
			database.execSQL("insert into "
					+ FOOD_LIST
					+ "(name, description, category, calories, image) values('Chicken - Drumstick', 'Chicken drumstick 1', " + FoodCategory.POULTRY + ", 110, "+R.drawable.food041+")");
			database.execSQL("insert into "
					+ FOOD_LIST
					+ "(name, description, category, calories, image) values('Ground Chicken', 'Chicken 4ozs 1', " + FoodCategory.POULTRY + ", 110, "+R.drawable.food073+")");
			database.execSQL("insert into "
					+ FOOD_LIST
					+ "(name, description, category, calories, image) values('Turkey Breast', 'Turkey', " + FoodCategory.POULTRY + ", 130, "+R.drawable.food135+")");
			database.execSQL("insert into "
					+ FOOD_LIST
					+ "(name, description, category, calories, image) values('Turkey Breast Cutlet', 'Turkey', " + FoodCategory.POULTRY + ", 130, "+R.drawable.food134+")");
			database.execSQL("insert into "
					+ FOOD_LIST
					+ "(name, description, category, calories, image) values('Turkey Sausage', 'Shady Brook - Turkey 1 patty or link', " + FoodCategory.POULTRY + ", 110, "+R.drawable.food136+")");
			database.execSQL("insert into "
					+ FOOD_LIST
					+ "(name, description, category, calories, image) values('Bologna', 'Serving size 2ozs'," + FoodCategory.SANDWICH_FILLERS + " , 150, "+R.drawable.food017+")");
			database.execSQL("insert into "
					+ FOOD_LIST
					+ "(name, description, category, calories, image) values('Pepperoni', '15 Slices'," + FoodCategory.SANDWICH_FILLERS + " , 135, "+R.drawable.food105+")");
			database.execSQL("insert into "
					+ FOOD_LIST
					+ "(name, description, category, calories, image) values('Roast Beef - all flavors', 'Roast Beef', " + FoodCategory.SANDWICH_FILLERS + ", 80, "+R.drawable.food122+")");
			database.execSQL("insert into "
					+ FOOD_LIST
					+ "(name, description, category, calories, image) values('Shrimp - Canned', 'Canned', " + FoodCategory.SEAFOOD + " , 40, "+R.drawable.food025+")");
			database.execSQL("insert into "
					+ FOOD_LIST
					+ "(name, description, category, calories, image) values('Tuna - Solid White in Water', 'Canned', " + FoodCategory.SEAFOOD + ", 70, "+R.drawable.food026+")");
			database.execSQL("insert into "
					+ FOOD_LIST
					+ "(name, description, category, calories, image) values('Cape Cod Potatoe Chips', 'Cape Cod Potatoe Chips', " + FoodCategory.SNACKS + ", 150, "+R.drawable.food079+")");
			database.execSQL("insert into "
					+ FOOD_LIST
					+ "(name, description, category, calories, image) values('Tostitos Tortillas Chips', 'Tostitos Tortillas Chips', " + FoodCategory.SNACKS + ", 140, "+R.drawable.food133+")");
			database.execSQL("insert into "
					+ FOOD_LIST
					+ "(name, description, category, calories, image) values('Wise All Natural Potato Chips', 'Tortilla and corn chips', " + FoodCategory.SNACKS + ", 140, "+R.drawable.food140+")");
			database.execSQL("insert into "
					+ FOOD_LIST
					+ "(name, description, category, calories, image) values('Wise Butter Flavoured Pop Corn', 'Pop corn - 1 1/2 cups', " + FoodCategory.SNACKS + ", 150, "+R.drawable.food109+")");
			database.execSQL("insert into "
					+ FOOD_LIST
					+ "(name, description, category, calories, image) values('Beef Broth', 'Broth', " + FoodCategory.SOUP_AND_STEW + ", 25, "+R.drawable.food011+")");
			database.execSQL("insert into "
					+ FOOD_LIST
					+ "(name, description, category, calories, image) values('Chicken Broth', 'Broth', " + FoodCategory.SOUP_AND_STEW + ", 20, "+R.drawable.food038+")");
			database.execSQL("insert into "
					+ FOOD_LIST
					+ "(name, description, category, calories, image) values('Cream of Broccoli', 'Campbell - condensed soups', " + FoodCategory.SOUP_AND_STEW + ", 180, "+R.drawable.food053+")");
			database.execSQL("insert into "
					+ FOOD_LIST
					+ "(name, description, category, calories, image) values('Manhattan Clam Chowder', 'Progresso', " + FoodCategory.SOUP_AND_STEW + ", 110, "+R.drawable.food044+")");
			database.execSQL("insert into "
					+ FOOD_LIST
					+ "(name, description, category, calories, image) values('Keebler Chocolate Chips Deluxe', 'Coockies', " + FoodCategory.SWEETS + ", 80, "+R.drawable.food042+")");
			database.execSQL("insert into "
					+ FOOD_LIST
					+ "(name, description, category, calories, image) values('Oreos - Regular', 'Coockies - 3 cookies', " + FoodCategory.SWEETS + ", 160, "+R.drawable.food099+")");
			database.execSQL("insert into "
					+ FOOD_LIST
					+ "(name, description, category, calories, image) values('Toaster Studel - Raspberry', 'Pillsbury', " + FoodCategory.TOASTER_PASTRIES + ", 190, "+R.drawable.food132+")");
			database.execSQL("insert into "
					+ FOOD_LIST
					+ "(name, description, category, calories, image) values('Artichokes', 'Artichokes', " + FoodCategory.VEGETABLES + ", 60, " +R.drawable.food004+")");
			database.execSQL("insert into "
					+ FOOD_LIST
					+ "(name, description, category, calories, image) values('Asparagus', 'Asparagus - 5 medium spears', " + FoodCategory.VEGETABLES + ", 17, "+R.drawable.food005+")");
			database.execSQL("insert into "
					+ FOOD_LIST
					+ "(name, description, category, calories, image) values('Avocado', 'Avocado - half', " + FoodCategory.VEGETABLES + ", 110, "+R.drawable.food006+")");
			database.execSQL("insert into "
					+ FOOD_LIST
					+ "(name, description, category, calories, image) values('Beets', 'Beets', " + FoodCategory.VEGETABLES + ", 58, " +R.drawable.food020+")");
			database.execSQL("insert into "
					+ FOOD_LIST
					+ "(name, description, category, calories, image) values('Bok Choy', 'Bok Choy', " + FoodCategory.VEGETABLES + ", 9, " +R.drawable.food016+")");
			database.execSQL("insert into "
					+ FOOD_LIST
					+ "(name, description, category, calories, image) values('Broccoli', 'Broccoli', " + FoodCategory.VEGETABLES + ", 63, " +R.drawable.food018+")");
			database.execSQL("insert into "
					+ FOOD_LIST
					+ "(name, description, category, calories, image) values('Carrots', 'Carrots', " + FoodCategory.VEGETABLES + ", 52, " +R.drawable.food029+")");
		}
		catch (SQLiteException se) {
			throw se;
		}

	}

	public static void InsertFoodGroups(Context context){
		try {
			// Open database
			database = context.openOrCreateDatabase(DB_NAME,
					Context.MODE_PRIVATE, null);
			
			database.execSQL("insert into " + FOOD_GROUPS
					+ "(id, foodGroup) values(" + FoodGroup.GRAINS  + ", 'Grains')");			
			database.execSQL("insert into " + FOOD_GROUPS
					+ "(id, foodGroup) values(" + FoodGroup.VEGETABLES + ", 'Vegetables')");
			database.execSQL("insert into " + FOOD_GROUPS
					+ "(id, foodGroup) values(" + FoodGroup.FRUITS + ", 'Fruits')");
			database.execSQL("insert into " + FOOD_GROUPS
					+ "(id, foodGroup) values(" + FoodGroup.DAIRY + ", 'Dairy')");
			database.execSQL("insert into " + FOOD_GROUPS
					+ "(id, foodGroup) values(" + FoodGroup.PROTEINS + ", 'Proteins')");
			database.execSQL("insert into " + FOOD_GROUPS
					+ "(id, foodGroup) values(" + FoodGroup.BEVERAGES + ", 'Beverages')");
			
		}
		catch (SQLiteException se){
			throw se;
		}
	}

	public static void InsertFoodCategories(Context context){

		try {
			// Open database
			database = context.openOrCreateDatabase(DB_NAME,
					Context.MODE_PRIVATE, null);

			// Populate the food categories table
			database.execSQL("insert into " + FOOD_CATEGORIES
					+ "(id, foodGroup, category) values(" + FoodCategory.BREADS + ", " + FoodGroup.GRAINS  + ",'Breads')");			
			database.execSQL("insert into " + FOOD_CATEGORIES
					+ "(id, foodGroup, category) values(" + FoodCategory.BEANS_AND_LEGUMES + ", " + FoodGroup.VEGETABLES  + ",'Beans Legumes')");
			database.execSQL("insert into " + FOOD_CATEGORIES
					+ "(id, foodGroup, category) values(" + FoodCategory.BEVERAGES + ", " + FoodGroup.BEVERAGES  + ",'Beverages')");
			database.execSQL("insert into " + FOOD_CATEGORIES
					+ "(id, foodGroup, category) values(" + FoodCategory.CEREAL_GRANOLA_AND_ENERGY_BARS + ", " + FoodGroup.GRAINS  + ",'Cereals Granola and Energy Bars')");
			database.execSQL("insert into " + FOOD_CATEGORIES
					+ "(id, foodGroup, category) values(" + FoodCategory.CRACKERS + ", " + FoodGroup.SNACKSANDSWEETS + ",'Crackers')");
			database.execSQL("insert into " + FOOD_CATEGORIES
					+ "(id, foodGroup, category) values(" + FoodCategory.DAIRY_PRODUCTS + ", " + FoodGroup.DAIRY  + ",'Dairy Products')");
			database.execSQL("insert into " + FOOD_CATEGORIES
					+ "(id, foodGroup, category) values(" + FoodCategory.DIPS_SALSA_AND_SPREADS + ", " + FoodGroup.OTHERS  + ",'Dips Salsa and Spreads')");
			database.execSQL("insert into " + FOOD_CATEGORIES
					+ "(id, foodGroup, category) values(" + FoodCategory.FATS_OIL_CONDIMENTS + ", " + FoodGroup.OTHERS  + ",'Fats Oil and Condiments')");
			database.execSQL("insert into " + FOOD_CATEGORIES
					+ "(id, foodGroup, category) values(" + FoodCategory.FROZEN_FOODS  + ", " + FoodGroup.FROZENFOOD  + ",'Frozen Foods')");
			database.execSQL("insert into " + FOOD_CATEGORIES
					+ "(id, foodGroup, category) values(" + FoodCategory.FRUITS + ", " + FoodGroup.FRUITS  + ",'Fruits')");
			database.execSQL("insert into " + FOOD_CATEGORIES
					+ "(id, foodGroup, category) values(" + FoodCategory.MEATS  + ", " + FoodGroup.PROTEINS  + ",'Meats')");
			database.execSQL("insert into " + FOOD_CATEGORIES
					+ "(id, foodGroup, category) values(" + FoodCategory.NUTS_AND_SEEDS   + ", " + FoodGroup.PROTEINS  + ",'Nuts and Seeds')");
			database.execSQL("insert into " + FOOD_CATEGORIES
					+ "(id, foodGroup, category) values(" + FoodCategory.POTATOES_RICE_PASTA_AND_GRAINS + ", " + FoodGroup.GRAINS  + ",'Potatoes Rice Pasta and Grains')");
			database.execSQL("insert into " + FOOD_CATEGORIES
					+ "(id, foodGroup, category) values(" + FoodCategory.POULTRY + ", " + FoodGroup.PROTEINS  + ",'Poultry')");
			database.execSQL("insert into " + FOOD_CATEGORIES
					+ "(id, foodGroup, category) values(" + FoodCategory.SANDWICH_FILLERS + ", " + FoodGroup.OTHERS  + ",'Sandwich Fillers')");
			database.execSQL("insert into " + FOOD_CATEGORIES
					+ "(id, foodGroup, category) values(" + FoodCategory.SEAFOOD + ", " + FoodGroup.PROTEINS  + ",'Seafood')");
			database.execSQL("insert into " + FOOD_CATEGORIES
					+ "(id, foodGroup, category) values(" + FoodCategory.SNACKS + ", " + FoodGroup.SNACKSANDSWEETS  + ",'Snacks')");
			database.execSQL("insert into " + FOOD_CATEGORIES
					+ "(id, foodGroup, category) values(" + FoodCategory.SOUP_AND_STEW + ", " + FoodGroup.OTHERS + ",'Soup and Stews')");
			database.execSQL("insert into " + FOOD_CATEGORIES
					+ "(id, foodGroup, category) values(" + FoodCategory.SWEETS + ", " + FoodGroup.SNACKSANDSWEETS  + ",'Sweets')");
			database.execSQL("insert into " + FOOD_CATEGORIES
					+ "(id, foodGroup, category) values(" + FoodCategory.TOASTER_PASTRIES + ", " + FoodGroup.OTHERS  + ",'Toaster Pastries')");
			database.execSQL("insert into " + FOOD_CATEGORIES
					+ "(id, foodGroup, category) values(" + FoodCategory.VEGETABLES + ", " + FoodCategory.BEVERAGES + ",'Vegetables')");
			
		}
		catch (SQLiteException se) {
			throw se;
		}
	}

	public static void DeleteDatabase(Context context) {
		context.deleteDatabase(DB_NAME);
	}
}
