package mqp.momometer.helpers;

import java.util.Vector;

import mqp.momometer.R;
import mqp.momometer.classes.FoodDataPoint;
import android.content.Context;
import android.graphics.Bitmap;
import android.graphics.Canvas;
import android.graphics.Color;
import android.graphics.Paint;
import android.graphics.Point;
import android.graphics.Rect;
import android.graphics.RectF;
import android.graphics.Typeface;
import android.graphics.Bitmap.Config;
import android.graphics.Paint.FontMetrics;

public class GraphDrawer {
	
    private static int draw_only_this_idx = -1;
    private static int[] drawSizes;
    private static Context context;
    
    public static Bitmap lineGraph(Context this_context, String title, String units, Bitmap bitmap, FoodDataPoint[] data)
	  {
    		context=this_context;
		// code to get bitmap onto screen
	        Bitmap output = Bitmap.createBitmap(bitmap.getWidth(),
	                bitmap.getHeight(), Config.ARGB_8888);
	            Canvas canvas = new Canvas(output);
	         
	            final int Rcolor= context.getResources().getColor(R.color.HeadLineBG2); 
	            final Paint paint = new Paint();
	            final Rect rect = new Rect(0, 0, bitmap.getWidth(), bitmap.getHeight());
	            final RectF rectF = new RectF(rect);   
	            final RectF border = new RectF(rectF.left+1,rectF.top+1,rectF.right-1,rectF.bottom-1);
	            final float roundPx = 12;
	         
	         // get the little rounded cornered outside
	            paint.setAntiAlias(true);
	            canvas.drawColor(context.getResources().getColor(R.color.HeadLineBG));
	            paint.setColor(Rcolor);
	            canvas.drawRoundRect(rectF, roundPx, roundPx, paint);
	            paint.setColor(context.getResources().getColor(R.color.HeadLineText));
	            paint.setStyle(Paint.Style.STROKE);
	            paint.setStrokeWidth(2);
	            canvas.drawRoundRect(border, roundPx, roundPx, paint);
	            
	            
	            // ---- Now just draw on this bitmap
	            
	            
	            // Set the labels info manually
	            String[] label_array = new String[6];
	            
/*	            label_array[1]="120.2";  // max
	            label_array[2]="102.5";    //min
*/	            
	            // code for future use
	            label_array[0]=title;
	            label_array[1]=String.valueOf(getYMax(data));  // Ymax
	            label_array[2]=String.valueOf(getYMin(data));    //Ymin
	            label_array[3]=String.valueOf(getXMax(data));  // Xmax
	            label_array[4]=String.valueOf(getXMin(data));    //Xmin
	            label_array[5]=units;
	            Vector labels = new Vector();
	            labels.add(label_array);
	            
	            drawGrid(canvas,labels);  
	            
	 
	            // set the data to be plotted and we should on our way
	            
	            Vector dataPlot = new Vector();  
	            
/*	            //placeholder values
	            dataPlot.add("102.5") ;
	            dataPlot.add("110.2") ;
	            dataPlot.add("112.6") ;
	            dataPlot.add("115.7") ;
	            dataPlot.add("121.4") ;
	            dataPlot.add("122.5") ;
	            dataPlot.add("122.2") ;
	            dataPlot.add("122.8") ;
	            dataPlot.add("120.2") ;
	            */
	            // in the future, use actual data
	            	for(int i=0;i<data.length;i++)
	            	{
	            		dataPlot.add(String.valueOf(data[i].y));
	            	}
	            
	            plotList(canvas ,  dataPlot ,  labels , title , 0 ); 
	            
	            canvas.drawBitmap(bitmap, rect, rect, paint);
	         
	        return output;
	  }    
    
    
    // these_labels is vector of [label,units,max.min]
  
    public static void  drawGrid(Canvas this_g,  Vector these_labels)
     {         
        double rounded_Ymax = 0.0;
        double rounded_Ymin = 0.0;
        double rounded_Xmax = 0.0;
        double rounded_Xmin = 0.0;
        double rounded_max_temp;
        Object currentElement;  
        String[] current_element_array;
        int left_margin_d, right_margin_d;
       
      

        if( draw_only_this_idx == -1)      
           currentElement = these_labels.elementAt(0);  // default  it to 1st one if non set 
        else
           currentElement = these_labels.elementAt(draw_only_this_idx);  // now just the 1st element
           
        current_element_array = (String[])currentElement;

        rounded_Ymax = get_ceiling_or_floor (Double.parseDouble(current_element_array[1]) , true);
        rounded_Ymin = get_ceiling_or_floor (Double.parseDouble(current_element_array[2]) , false);
        rounded_Xmax = get_ceiling_or_floor (Double.parseDouble(current_element_array[3]) , true);
        rounded_Xmin = get_ceiling_or_floor (Double.parseDouble(current_element_array[4]) , false);


       // ok so now we have the max value of the set just get a cool ceiling and we go on
        final Paint paint = new Paint();  
        paint.setTextSize(15);
        
       left_margin_d =  getCurTextLengthInPixels(paint, (Double.toString(rounded_Ymax)+" "+current_element_array[5]));
       //keep the position for later drawing -- leave space for the legend
       int p_height = 170;
       int p_width = 220;
       int[] tmp_draw_sizes = {2 + left_margin_d, 25,p_width - 2 - left_margin_d ,p_height - 25 -5};
       drawSizes = tmp_draw_sizes; //keep it for later processing

        
        //with the margins worked out draw the plotting grid
       paint.setStyle(Paint.Style.FILL); 
       paint.setColor(Color.WHITE );  
       
       // Android does by coords
       this_g.drawRect(drawSizes[0], drawSizes[1],drawSizes[0]+ drawSizes[2], drawSizes[1]+ drawSizes[3] , paint);
       
       
       paint.setColor(Color.GRAY);
       
       
        // finally draw the grid
      
       
       paint.setStyle(Paint.Style.STROKE); 
       this_g.drawRect(drawSizes[0], drawSizes[1],drawSizes[0]+ drawSizes[2], drawSizes[1]+ drawSizes[3] , paint);

           for(int i=1; i < 5 ; i++)
           {

               this_g.drawLine(drawSizes[0], drawSizes[1] + (i * drawSizes[3] / 5), drawSizes[0] + drawSizes[2], drawSizes[1] + (i * drawSizes[3] / 5), paint);
               this_g.drawLine(drawSizes[0]+ (i * drawSizes[2] / 5), drawSizes[1], drawSizes[0] + (i * drawSizes[2] / 5), drawSizes[1] + drawSizes[3], paint);
               
               

           }
           //print title
           paint.setTextSize(15);
           paint.setColor(Color.BLACK);
           paint.setTextAlign(Paint.Align.CENTER);
           this_g.drawText(current_element_array[0], (drawSizes[0]*2 + drawSizes[2])/2 ,drawSizes[1] - 7 , paint );

          // print axes
           printYAxisValues(this_g, current_element_array[5] , Double.toString(rounded_Ymax) , Double.toString(rounded_Ymin));
           printXAxisValues(this_g, Double.toString(rounded_Xmax), Double.toString(rounded_Xmin));

         
     }  // --- end of draw_grid --- 
    
     public static void printYAxisValues(Canvas thisDrawingArea, String units , String current_max , String current_min)
    {
          String this_str;
          double delta = ( Double.valueOf(current_max).doubleValue()  -  Double.valueOf(current_min).doubleValue() ) / 5;
          final Paint paint = new Paint();

          paint.setColor(Color.BLACK);
          paint.setTypeface( Typeface.SANS_SERIF ); 

          //Font smallyFont = Font.getDefault().derive(Font.PLAIN, 12);
         // thisDrawingArea.setFont(smallyFont);
          paint.setTextSize(12);
          

          for(int i = 0; i<6 ; i++)
          {
	             // 'work our the values so is proper
	
	
	          this_str =Double.toString( (Double.valueOf(current_min).doubleValue()  + delta * i) );
	
	
	          final int point = this_str.indexOf('.');
	          if (point > 0) {
	              // If has a decimal point, may need to clip off 
	              this_str =  this_str.substring(0,point);
	          }
	          this_str += " "+units;
	              if (i == 5) continue;
	              else
	                  thisDrawingArea.drawText(this_str,  6, drawSizes[1] + drawSizes[3]  - (i * drawSizes[3] / 5), paint);
          }


                   
    }  // --- end of printYAxisValues ---
     
     public static void printXAxisValues(Canvas thisDrawingArea, String current_max , String current_min )
     {
           String this_str;
           double delta = ( Double.valueOf(current_max).doubleValue()  -  Double.valueOf(current_min).doubleValue() ) / 5;
           final Paint paint = new Paint();

           paint.setColor( Color.BLACK); 
           paint.setTypeface( Typeface.SANS_SERIF ); 
           paint.setTextAlign(Paint.Align.CENTER);
           paint.setTextSize(10);
           

           for(int i = 0; i<6 ; i++)
           {
 	             // 'work our the values so is proper
 	
 	
 	          this_str =Double.toString( (Double.valueOf(current_min).doubleValue()  + delta * i) );
 	
 	
 	          final int point = this_str.indexOf('.');
 	          if (point > 0) {
 	              // If has a decimal point, may need to clip off 
 	              this_str =  this_str.substring(0,point);
 	          }
 	          thisDrawingArea.drawText(this_str,  drawSizes[0]+ (i * drawSizes[2] / 5), drawSizes[1] + drawSizes[3] + 12 , paint );
 	              
           }
       		paint.setTextSize(13);
       		thisDrawingArea.drawText("Pregnancy Week",  ((drawSizes[0]*2 + drawSizes[2])/2) ,drawSizes[1] + drawSizes[3] + 27, paint );
              
     }  // --- end of printAxisValues ---

    private static Point  scale_point(int this_x , double this_y  , Point drawPoint , 
            int scr_x  , int scr_y  , int scr_width  , int src_height  , 
            double maxX  , double minX  , double  maxY  , double minY  )
       {
           int temp_x, temp_y;
           Point temp = new Point();   
           
           if (maxY == minY)  //skip bad data
               return null;

           //don't touch it if is nothing
           try
           {
                   temp_x = scr_x + (int)( ((double)this_x - minX) * ((double)scr_width / (maxX - minX)) );
                   temp_y = scr_y + (int)( (maxY - this_y) * ((double)src_height / (maxY - minY)) );
                
                   temp.x = temp_x;
                   temp.y= temp_y;
                   drawPoint = temp;
                   
                   
           } 
           catch  (Exception e)
           {
        
              return (null);
           }
           
           return temp;
           
       } // --- end of scale_point --

    public static boolean plotList(Canvas this_g, Vector dataList , Vector labels , String this_title , int only_this_idx ) 
    {
             int idx;
             int lRow ;
             int nParms;
             int  i, numPoints, shifted_idx ; 
             int previous_x, previous_y ;
             int current_x=0, current_y=0 ; 
             //Dim ShowMarker As Object
             Point current_point = new Point();
             current_point.set(0,0);
     
             double current_maxX, current_minX, current_maxY=20, current_minY=0, current_rangeY;
             int current_start_x, current_numPoints; 
   
            int POINTS_TO_CHANGE = 30;
            double current_OBD_val;
  
             //Object currentElement;  
             String currentElement; 
             String[] current_element_array;
             Object currentElement2;  
             String[] current_element_array2;
     
             final Paint paint = new Paint();

             try // catch in this block for some thing
             {
       
                   numPoints = dataList.size();
                   {
                        current_start_x = 0;
                        current_numPoints = numPoints;
                        current_maxX = current_numPoints;
                        current_minX = 0;
                   }
  
                   //'Create the plot points for this series from the ChartPoints array:
   
                   currentElement = (String)dataList.elementAt(0);
                   
                   //the lines have to come out good
                    paint.setStyle(Paint.Style.FILL_AND_STROKE);
                    paint.setStrokeWidth(2);
                    paint.setColor(context.getResources().getColor(R.color.GraphLine));
                    
//                  
                   //for(  nParms = 0 ; nParms < current_element_array.length ; nParms++ )
                   nParms = only_this_idx;
                   {
    
                       //get current item labels
                        currentElement2 = labels.elementAt(nParms);
                        current_element_array2  = (String[]) currentElement2;
                        
                        current_maxY = get_ceiling_or_floor (Double.parseDouble(current_element_array2[1]) , true);
                        current_minY = get_ceiling_or_floor (Double.parseDouble(current_element_array2[2]) , false);
                        
                        current_numPoints = dataList.size();                     
                        current_maxX = current_numPoints;
    
                      currentElement = (String)dataList.elementAt(0);
                      current_OBD_val =  Double.parseDouble(currentElement);
                      
                      current_point = scale_point(0, current_OBD_val, current_point, 
                              drawSizes[0], drawSizes[1], drawSizes[2], drawSizes[3], 
                              current_maxX, current_minX, current_maxY, current_minY); //'(CInt(curAxisValues.Mins(nParms - 2) / 5) + 1) * 5)
                       
                       current_x = current_point.x;
                       current_y = current_point.y;

                                              
                      // the point is only cool when samples are low
                       if ( current_numPoints < POINTS_TO_CHANGE)
                         this_g.drawRect(current_x-2, current_y-2, current_x-2 + 4,current_y-2+ 4 , paint); 
                       
                       previous_x = current_x;
                       previous_y = current_y;

                      

                       //'go and plot point for this parm -- point after the 1st one 
                       for (lRow = current_start_x +1 ; lRow< current_start_x + current_numPoints -1 ; lRow++)
                       {
        
                           currentElement = (String)dataList.elementAt(lRow);
                           
                           current_OBD_val = Double.parseDouble(currentElement);
                             
                           
                                 
                                 
                            //'work out an approx if cur Y values not avail(e.g. nothing)
                           // if (! (current_element_array[nParms ] == null ) )   //skip bad one
                             if( current_OBD_val == Double.NaN) continue;  //skip bad one
                            {                  
       
                               
                                current_point=scale_point(lRow, current_OBD_val, current_point,  
                                    drawSizes[0], drawSizes[1], drawSizes[2], drawSizes[3], 
                                    current_maxX, current_minX, current_maxY, current_minY);
    
                                current_x = current_point.x;
                                current_y = current_point.y;
                                
                                if ( current_numPoints < POINTS_TO_CHANGE)
                                   this_g.drawRect(current_x-2, current_y-2, current_x-2 +4, current_y-2 + 4, paint ); 
 
                               this_g.drawLine( previous_x, previous_y, current_x, current_y, paint);
                               previous_x = current_x;
                               previous_y = current_y;
                                                        
                            } // ' if end of this_array(lRow, nParms - 1)<> nothing
                                 
                   } // end of for lrow
                               
               } // end of for nParmns


            //this_g.invalidate();
            return( true);
        }
        catch (Exception e)
        {
            return( false);
            
        }

    } // --- end of plotList  --

    
    // need the width of the labels
    private static int getCurTextLengthInPixels(Paint this_paint, String this_text) {
        FontMetrics tp = this_paint.getFontMetrics();
        Rect rect = new Rect();
        this_paint.getTextBounds(this_text, 0, this_text.length(), rect);
       return rect.width();
    } // --- end of getCurTextLengthInPixels  ---

    
    public static double get_ceiling_or_floor(double this_val ,  boolean is_max  )
    {
    	
    	double this_min_tmp;
        int  this_sign;
        int  this_10_factor=0;
        double this_rounded;

        if (this_val == 0.0) 
        {
            this_rounded = 0.0;
            return this_rounded;
        }

        this_min_tmp = Math.abs(this_val);

        if (this_min_tmp >= 1.0 && this_min_tmp < 10.0) 
            this_10_factor = 1;
        else if (this_min_tmp >= 10.0 && this_min_tmp < 100.0) 
            this_10_factor = 10;
        else if (this_min_tmp >= 100.0 && this_min_tmp < 1000.0) 
            this_10_factor = 100;
        else if (this_min_tmp >= 1000.0 && this_min_tmp < 10000.0) 
            this_10_factor = 1000;
        else if (this_min_tmp >= 10000.0 && this_min_tmp < 100000.0) 
            this_10_factor = 10000;
       
        if(is_max)
        	this_rounded = (double)(((int)(this_min_tmp / this_10_factor)+1) * this_10_factor);
    	else
    		this_rounded = (double)(((int)(this_min_tmp / this_10_factor)) * this_10_factor);

       

        return  this_rounded;

} // --- end of get_ceiling_or_floor ---
    
    public static double getYMax(FoodDataPoint[] data){
    	double current=0;
    	for(int i=0;i<data.length;i++)
    		if(data[i].y>current)
    			current=data[i].y;    	    	    	
    	return current;
    }

    public static double getYMin(FoodDataPoint[] data){
    	double current=data[0].y;
    	for(int i=0;i<data.length;i++)
    		if(data[i].y<current)
    			current=data[i].y;    	
    	return current;
    }
    public static double getXMax(FoodDataPoint[] data){
    	double current=0;
    	for(int i=0;i<data.length;i++)
    		if(data[i].x>current)
    			current=data[i].x;    	    	    	
    	return current;
    }

    public static double getXMin(FoodDataPoint[] data){
    	double current=data[0].x;
    	for(int i=0;i<data.length;i++)
    		if(data[i].x<current)
    			current=data[i].x;    	
    	return current;
    }
    
    
}
