package mqp.momometer.helpers;

import java.text.DateFormatSymbols;
import java.text.DecimalFormat;
import java.text.NumberFormat;
import java.text.SimpleDateFormat;
import java.util.Calendar;
import java.util.Date;
import mqp.momometer.helpers.UnitConversions;

import android.content.Context;

import mpq.momometer.repositories.SharedPreferencesAdapter;

public class HelperFunctions {
	
	/**
	 * Return a date object with the current date and time
	 * @return
	 */
	public static Date getTimeStamp()
	{
		Date d = Calendar.getInstance().getTime();
		return d;
	}
	
	/**
	 * Returns a string with the current timestamp
	 * @return String
	 */
	public static String getTimeStampString()
	{
		Date d = getTimeStamp();
		return formatDate(d);
	}
	
	/**
	 * Returns a string with the format MM/dd/yy hh:mm a 
	 * @return String
	 */
	public static String formatDate(Date d)
	{
		SimpleDateFormat formatter = new SimpleDateFormat("MM/dd/yy hh:mm a");
		String dateString = formatter.format(d);
		return dateString;
	}
	
	/**
	 * 
	 * @return
	 */
	public static int getCurrentWeek(Context context)
	{
		int startingWeek = SharedPreferencesAdapter.getStartingWeek(context);
		Date startingDate = SharedPreferencesAdapter.getStartTimestamp(context);
		Date endingDate = new Date();				
		int diffInWeeks = getDiffInWeeks(startingDate, endingDate);
		
		return startingWeek + diffInWeeks;
	}
	
	/**
	 * Returns the difference in number of weeks between the start and the end dates
	 * @param start
	 * @param end
	 * @return int
	 */
	public static int getDiffInWeeks(Date start, Date end)
	{
		int diff = getDateDiffInDays(start, end);
		return diff / 7;
	}
	
	/**
	 * Returns the difference in number of days between the start and the end dates
	 * @param start
	 * @param end 
	 * @return int
	 */
	public static int getDateDiffInDays(Date start, Date end)
	{
		long diff = end.getTime() - start.getTime();
		
		return (int) (diff / (1000 * 60 * 60 * 24));
	}
	
	/**
	 * Returns the name of the month given its number
	 * @param month
	 * @return
	 */
	public static String getMonthStringFromInt(int month)
	{
		DateFormatSymbols formatter = new DateFormatSymbols();
		return formatter.getMonths()[month];
	}
	
	/**
	 * Returns the prepregnancy BMI values in kg/m2
	 * @param context - the application context
	 * @return double - the BMI value
	 */
	public static double getPrepregnancyBMI(Context context)
	{
		double height = 
			SharedPreferencesAdapter.getStartingHeightInches(context) * UnitConversions.FEETTOMETERS +
			SharedPreferencesAdapter.getStartingHeightInches(context) * UnitConversions.INCHESTOMETERS;
		double weight = SharedPreferencesAdapter.getStartingWeight(context) * UnitConversions.LBSTOKGS;
		
		return weight / height;
			
	}
	
	/**
	 * Formats the given double with 2 decimal places
	 * @param number The double to format
	 */
	public static double formatDouble(double number){
		DecimalFormat df = new DecimalFormat("#.##");
		return Double.valueOf(df.format(number));
	}
}
